@@ -1,6 +1,6 @@
 // callbacks.h
 // LiVES
-// (c) G. Finch <salsaman@gmail.com> 2003 - 2016
+// (c) G. Finch <salsaman+lives@gmail.com> 2003 - 2017
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -11,6 +11,8 @@ void lives_exit(int signum);
 
 void lives_notify(int msgnumber, const char *msgstring);
 
+void lives_notify_int(int msgnumber, int msgint);
+
 void on_effects_paused(LiVESButton *, livespointer);
 
 void on_cancel_keep_button_clicked(LiVESButton *, livespointer);
@@ -39,6 +41,10 @@ void on_open_utube_activate(LiVESMenuItem *, livespointer);
 
 void on_stop_clicked(LiVESMenuItem *, livespointer);
 
+#ifdef LIBAV_TRANSCODE
+void on_transcode_activate(LiVESMenuItem *, livespointer);
+#endif
+
 void on_save_selection_activate(LiVESMenuItem *, livespointer);
 
 void on_save_as_activate(LiVESMenuItem *, livespointer);
@@ -75,7 +81,7 @@ void on_merge_activate(LiVESMenuItem *, livespointer);
 
 void on_delete_activate(LiVESMenuItem *, livespointer);
 
-void on_select_all_activate(LiVESMenuItem *, livespointer);
+void on_select_all_activate(LiVESWidget *, livespointer);
 
 void on_select_new_activate(LiVESMenuItem *, livespointer);
 
@@ -275,8 +281,6 @@ void on_ok_export_audio_clicked(LiVESButton *, livespointer);
 
 void on_append_audio_activate(LiVESMenuItem *, livespointer);
 
-void on_menubar_activate_menuitem(LiVESMenuItem *, livespointer);
-
 void on_rb_audrec_time_toggled(LiVESToggleButton *, livespointer);
 
 void on_recaudclip_activate(LiVESMenuItem *, livespointer);
@@ -319,6 +323,8 @@ void on_showfct_activate(LiVESMenuItem *, livespointer);
 
 void on_boolean_toggled(LiVESObject *, livespointer);
 
+void after_audio_toggled(LiVESWidget *, livespointer);
+
 void on_showsubs_toggled(LiVESObject *, livespointer);
 
 void on_show_messages_activate(LiVESMenuItem *, livespointer);
