@@ -629,12 +629,9 @@ lives_render_error_t realfx_progress(boolean reset) {
   if (has_video_filters(FALSE) || resize_instance != NULL) {
     mainw->rowstride_alignment = mainw->rowstride_alignment_hint;
 
-    layer = weed_plant_new(WEED_PLANT_CHANNEL);
-    weed_set_int_value(layer, WEED_LEAF_CLIP, mainw->current_file);
-    weed_set_int_value(layer, WEED_LEAF_FRAME, i);
-
-    frameticks = (i - cfile->start + 1.) / cfile->fps * U_SECL;
+    frameticks = (i - cfile->start + 1.) / cfile->fps * TICKS_PER_SECOND;
 
+    layer = weed_layer_new_for_frame(mainw->current_file, i);
     if (!pull_frame(layer, get_image_ext_for_type(cfile->img_type), frameticks)) {
       // do_read_failed_error_s() cannot be used here as we dont know the filename
       lives_snprintf(mainw->msg, 256, "error|missing image %d", i);
@@ -862,13 +859,12 @@ weed_plant_t *on_rte_apply(weed_plant_t *layer, int opwidth, int opheight, weed_
   } else layers[1] = NULL;
 
   if (resize_instance != NULL) {
-    lives_filter_error_t filter_error;
     weed_plant_t *init_event = weed_plant_new(WEED_PLANT_EVENT);
     weed_set_int_value(init_event, WEED_LEAF_IN_TRACKS, 0);
     weed_set_int_value(init_event, WEED_LEAF_OUT_TRACKS, 0);
 
-    filter_error = weed_apply_instance(resize_instance, init_event, layers, 0, 0, tc);
-    filter_error = filter_error; // stop compiler complaining
+    weed_apply_instance(resize_instance, init_event, layers, 0, 0, tc);
+
     retlayer = layers[0];
     weed_plant_free(init_event);
   } else {
@@ -935,8 +931,9 @@ deint1:
 
 
 weed_plant_t *get_blend_layer(weed_timecode_t tc) {
-  lives_clip_t *blend_file;
   static weed_timecode_t blend_tc = 0;
+
+  lives_clip_t *blend_file;
   weed_timecode_t ntc = tc;
 
   if (mainw->blend_file == -1 || mainw->files[mainw->blend_file] == NULL) return NULL;
@@ -955,10 +952,7 @@ weed_plant_t *get_blend_layer(weed_timecode_t tc) {
 
   blend_tc = ntc;
 
-  mainw->blend_layer = weed_plant_new(WEED_PLANT_CHANNEL);
-  weed_set_int_value(mainw->blend_layer, WEED_LEAF_CLIP, mainw->blend_file);
-  weed_set_int_value(mainw->blend_layer, WEED_LEAF_FRAME, blend_file->frameno);
-
+  mainw->blend_layer = weed_layer_new_for_frame(mainw->blend_file, blend_file->frameno);
   pull_frame_threaded(mainw->blend_layer, get_image_ext_for_type(blend_file->img_type), tc);
 
   return mainw->blend_layer;
