@@ -136,7 +136,7 @@ void framedraw_add_reset(LiVESVBox *box, lives_special_framedraw_rect_t *framedr
 
   framedraw_add_label(box);
 
-  mainw->framedraw_reset = lives_button_new_from_stock(LIVES_STOCK_REFRESH, NULL);
+  mainw->framedraw_reset = lives_standard_button_new_from_stock(LIVES_STOCK_REFRESH, NULL);
   hbox_rst = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(box), hbox_rst, FALSE, FALSE, 0);
 
@@ -243,7 +243,7 @@ void widget_add_framedraw(LiVESVBox *box, int start, int end, boolean add_previe
   lives_scale_set_draw_value(LIVES_SCALE(mainw->framedraw_scale), FALSE);
 
   rfx = (lives_rfx_t *)lives_widget_object_get_data(LIVES_WIDGET_OBJECT(lives_widget_get_toplevel(LIVES_WIDGET(box))), "rfx");
-  mainw->framedraw_preview = lives_button_new_from_stock(LIVES_STOCK_REFRESH, _("_Preview"));
+  mainw->framedraw_preview = lives_standard_button_new_from_stock(LIVES_STOCK_REFRESH, _("_Preview"));
   lives_box_pack_start(LIVES_BOX(hbox), mainw->framedraw_preview, TRUE, FALSE, 0);
   lives_widget_set_sensitive(mainw->framedraw_spinbutton, FALSE);
   lives_widget_set_sensitive(mainw->framedraw_scale, FALSE);
@@ -571,7 +571,7 @@ void load_rfx_preview(lives_rfx_t *rfx) {
     img_ext = get_image_ext_for_type(cfile->img_type);
   }
 
-  tc = ((mainw->framedraw_frame - 1.)) / cfile->fps * U_SECL;
+  tc = ((mainw->framedraw_frame - 1.)) / cfile->fps * TICKS_PER_SECOND;
   pixbuf = pull_lives_pixbuf_at_size(mainw->current_file, mainw->framedraw_frame, (char *)img_ext,
                                      tc, (double)cfile->hsize,
                                      (double)cfile->vsize, LIVES_INTERP_BEST);
@@ -609,7 +609,7 @@ void load_framedraw_image(LiVESPixbuf *pixbuf) {
     // can happen if we preview for rendered generators
     if ((mainw->multitrack == NULL || mainw->current_file != mainw->multitrack->render_file) && mainw->framedraw_frame == 0) return;
 
-    tc = ((mainw->framedraw_frame - 1.)) / cfile->fps * U_SECL;
+    tc = ((mainw->framedraw_frame - 1.)) / cfile->fps * TICKS_PER_SECOND;
     pixbuf = pull_lives_pixbuf_at_size(mainw->current_file, mainw->framedraw_frame, img_ext, tc,
                                        (double)cfile->hsize, (double)cfile->vsize,
                                        LIVES_INTERP_BEST);
@@ -620,7 +620,7 @@ void load_framedraw_image(LiVESPixbuf *pixbuf) {
       weed_layer_free(mainw->fd_layer_orig);
     }
 
-    mainw->fd_layer_orig = weed_layer_new(0, 0, NULL, WEED_PALETTE_END);
+    mainw->fd_layer_orig = weed_layer_create(0, 0, NULL, WEED_PALETTE_END);
 
     if (!pixbuf_to_layer(mainw->fd_layer_orig, pixbuf)) lives_object_unref(pixbuf);
 
