@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@gmail.com) 2003 - 2017
+// (c) G. Finch (salsaman@gmail.com) 2003 - 2018
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 */
 
-
 // begin legal warning
 /*
     NO WARRANTY
@@ -44,12 +43,10 @@ POSSIBILITY OF SUCH DAMAGES.
 */
 // end legal warning
 
-
 // Have fun, and let's fight for Free Speech, Open Media and True Creativity !
 // - Salsaman
 
-
-// note: preferred coding style is: astyle --style=java -H -Y -s2 -U -k3 -W3 -xC140 -xL
+// note: preferred coding style is: astyle --style=java -H -Y -s2 -U -k3 -W3 -xC140 -xL -p
 
 #ifndef HAS_LIVES_MAIN_H
 #define HAS_LIVES_MAIN_H
@@ -82,6 +79,11 @@ POSSIBILITY OF SUCH DAMAGES.
 
 #endif
 
+#if !GTK_CHECK_VERSION(3, 0, 0)
+// borked in < 3.0
+#undef HAVE_WAYLAND
+#endif
+
 #ifdef HAVE_WAYLAND
 #include <gdk/gdkwayland.h>
 #endif
@@ -225,7 +227,7 @@ typedef int lives_pgid_t;
 
 #define LIVES_DEVICE_DIR "/dev/"
 
-#define LIVES_COPYRIGHT_YEARS "2002 - 2017"
+#define LIVES_COPYRIGHT_YEARS "2002 - 2018"
 
 #define LIVES_WEBSITE PACKAGE_URL
 #define LIVES_MANUAL_URL LIVES_WEBSITE "/manual/"
@@ -272,11 +274,16 @@ typedef int lives_pgid_t;
 #endif
 
 #ifndef IS_SOLARIS
-#define LIVES_INLINE inline
+#define LIVES_INLINE static inline
+#define LIVES_GLOBAL_INLINE inline
 #else
-#define LIVES_INLINE
+#define LIVES_INLINE static
+#define LIVES_GLOBAL_INLINE
+#define LIVES_LOCAL_INLINE
 #endif
 
+#define LIVES_LOCAL_INLINE LIVES_INLINE
+
 #include <limits.h>
 #include <float.h>
 
@@ -303,6 +310,7 @@ typedef int lives_pgid_t;
 #endif
 
 #ifdef PRODUCE_LOG
+// disabled by default
 #define LIVES_LOG "lives.log"
 #endif
 
@@ -505,6 +513,27 @@ typedef enum {
 
 #define CLIP_NAME_MAXLEN 256
 
+#define IS_VALID_CLIP(clip) (clip >= 0 && mainw->files[clip] != NULL)
+#define CURRENT_CLIP_IS_VALID IS_VALID_CLIP(mainw->current_file)
+
+#define CLIP_HAS_VIDEO(clip) (IS_VALID_CLIP(clip) && mainw->files[clip]->frames > 0)
+#define CURRENT_CLIP_HAS_VIDEO CLIP_HAS_VIDEO(mainw->current_file)
+
+#define CLIP_HAS_AUDIO(clip) (IS_VALID_CLIP(clip) && mainw->files[clip]->achans > 0 && mainw->files[clip]->asampsize > 0)
+#define CURRENT_CLIP_HAS_AUDIO CLIP_HAS_AUDIO(mainw->current_file)
+
+#define CLIP_VIDEO_TIME(clip) ((double)(IS_VALID_CLIP(clip) ? mainw->files[clip]->video_time : 0.))
+
+#define CLIP_LEFT_AUDIO_TIME(clip) ((double)(IS_VALID_CLIP(clip) ? mainw->files[clip]->laudio_time : 0.))
+
+#define CLIP_RIGHT_AUDIO_TIME(clip) ((double)(IS_VALID_CLIP(clip) ? (mainw->files[clip]->achans > 1 ? mainw->files[clip]->raudio_time : 0.) : 0.))
+
+#define CLIP_AUDIO_TIME(clip) ((double)(CLIP_LEFT_AUDIO_TIME(clip) >= CLIP_RIGHT_AUDIO_TIME(clip) ? CLIP_LEFT_AUDIO_TIME(clip) : CLIP_RIGHT_AUDIO_TIME(clip)))
+
+#define CLIP_TOTAL_TIME(clip) ((double)(CLIP_VIDEO_TIME(clip) > CLIP_AUDIO_TIME(clip) ? CLIP_VIDEO_TIME(clip) : CLIP_AUDIO_TIME(clip)))
+
+#define CURRENT_CLIP_TOTAL_TIME CLIP_TOTAL_TIME(mainw->current_file)
+
 /// corresponds to one clip in the GUI
 typedef struct {
   // basic info (saved during backup)
@@ -582,8 +611,7 @@ typedef struct {
   boolean nokeep;
 
   // various times; total time is calculated as the longest of video, laudio and raudio
-  double total_time;
-  double video_time;
+  double video_time; // TODO: deprecate, calculate CLIP_VIDEO_TIME from frames and fps
   double laudio_time;
   double raudio_time;
   double pointer_time;
@@ -690,6 +718,8 @@ typedef struct {
   int cb_src; ///< source clip for clipboard
 
   boolean needs_update; ///< loaded values were incorrect, update header
+
+  float **audio_waveform; ///< values for drawing the audio wave
 } lives_clip_t;
 
 typedef struct {
@@ -998,7 +1028,7 @@ boolean read_file_details(const char *file_name, boolean only_check_for_audio);
 boolean add_file_info(const char *check_handle, boolean aud_only);
 boolean save_file_comments(int fileno);
 boolean reload_clip(int fileno, int maxframe);
-void wait_for_bg_audio_sync(lives_clip_t *sfile);
+void wait_for_bg_audio_sync(int fileno);
 void reget_afilesize(int fileno);
 ulong deduce_file(const char *filename, double start_time, int end);
 ulong open_file(const char *filename);
@@ -1122,9 +1152,9 @@ void add_message_scroller(LiVESWidget *conter);
 void resize_widgets_for_monitor(boolean get_play_times);
 #if GTK_CHECK_VERSION(3, 0, 0)
 void calibrate_sepwin_size(void);
-boolean expose_pim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
-boolean expose_sim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
-boolean expose_eim(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data);
+boolean expose_pim(LiVESWidget *, lives_painter_t *, livespointer);
+boolean expose_sim(LiVESWidget *, lives_painter_t *, livespointer);
+boolean expose_eim(LiVESWidget *, lives_painter_t *, livespointer);
 #endif
 
 // system calls in utils.c
@@ -1137,10 +1167,12 @@ int lives_creat_buffered(const char *pathname, int mode);
 int lives_close_buffered(int fd);
 void lives_close_all_file_buffers(void);
 off_t lives_lseek_buffered_rdonly(int fd, off_t offset);
+off_t lives_lseek_buffered_rdonly_absolute(int fd, off_t offset);
 ssize_t lives_write(int fd, livesconstpointer buf, size_t count, boolean allow_fail);
 ssize_t lives_write_buffered(int fd, const char *buf, size_t count, boolean allow_fail);
 ssize_t lives_write_le(int fd, livesconstpointer buf, size_t count, boolean allow_fail);
 ssize_t lives_write_le_buffered(int fd, livesconstpointer buf, size_t count, boolean allow_fail);
+ssize_t file_buffer_flush(int fd);
 ssize_t lives_read(int fd, void *buf, size_t count, boolean allow_less);
 ssize_t lives_read_buffered(int fd, void *buf, size_t count, boolean allow_less);
 ssize_t lives_read_le(int fd, void *buf, size_t count, boolean allow_less);
@@ -1188,7 +1220,7 @@ uint64_t lives_10pow(int pow) GNU_CONST;
 double lives_fix(double val, int decimals) GNU_CONST;
 int get_approx_ln(uint32_t val) GNU_CONST;
 
-int64_t lives_get_current_ticks(void);
+int64_t lives_get_current_ticks(int64_t delta_seconds, int64_t delta_usec);
 boolean lives_alarm_get(int alarm_handle);
 int lives_alarm_set(int64_t ticks);
 void lives_alarm_clear(int alarm_handle);
@@ -1220,8 +1252,14 @@ void set_menu_text(LiVESWidget *menu, const char *text, boolean use_mnemonic);
 void get_menu_text(LiVESWidget *menu, char *text);
 void get_menu_text_long(LiVESWidget *menuitem, char *text);
 void reset_clipmenu(void);
-void get_play_times(void);
-void get_total_time(lives_clip_t *file);
+
+double lives_ce_update_timeline(int frame, double x);  ///< pointer position in timeline
+void get_play_times(void); ///< recalculate video / audio lengths and draw the timer bars
+void update_play_times(void); ///< like get_play_times, but will force redraw audio waveforms
+void update_timer_bars(int posx, int posy, int width, int height, int which); ///< draw the timer bars
+void redraw_timer_bars(double oldx, double newx, int which); ///< paint a damage region
+void get_total_time(lives_clip_t *file); ///< calculate laudio, raudio and video time (may be deprecated and replaced with macros)
+
 uint32_t get_signed_endian(boolean is_signed, boolean little_endian);
 void fullscreen_internal(void);
 void switch_to_int_player(void);
@@ -1250,6 +1288,7 @@ double calc_time_from_frame(int clip, int frame);
 int calc_frame_from_time(int filenum, double time);   ///< nearest frame start
 int calc_frame_from_time2(int filenum, double time);  ///< nearest frame end
 int calc_frame_from_time3(int filenum, double time);  ///< nearest frame mid
+int calc_frame_from_time3(int filenum, double time);  ///< nearest frame start, no maximum
 
 boolean check_for_ratio_fps(double fps);
 double get_ratio_fps(const char *string);
@@ -1285,7 +1324,7 @@ int verhash(char *version);
 void set_undoable(const char *what, boolean sensitive);
 void set_redoable(const char *what, boolean sensitive);
 void zero_spinbuttons(void);
-void draw_little_bars(double ptrtime);
+void draw_little_bars(double ptrtime, int which);
 void set_sel_label(LiVESWidget *label);
 void clear_mainw_msg(void);
 int get_token_count(const char *string, int delim);
