@@ -1,14 +1,12 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman@gmail.com> 2003 - 2015
+// (c) G. Finch <salsaman+lives@gmail.com> 2003 - 2017
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
-
 #ifndef HAS_LIVES_MAINWINDOW_H
 #define HAS_LIVES_MAINWINDOW_H
 
-
 #include <pthread.h>
 
 #include "effects-data.h"
@@ -25,20 +23,18 @@
 
 // hardware related prefs
 
-/// fraction of a second quantisation for event timing; must match U_SECL, and must be a multiple of 10>=1000000
+/// fraction of a second quantisation for event timing
 ///
-/// >10**8 is not recommended, since we sometimes store seconds in a double
-#define U_SEC 100000000.
-#define U_SECL (int64_t)100000000
-#define U_SEC_RATIO (U_SECL/1000000) ///< how many U_SECs (ticks) in a microsecond [default 100]
-
-
-#define LIVES_SHORTEST_TIMEOUT  (2. * U_SEC) // 2 sec timeout
-#define LIVES_SHORT_TIMEOUT  (5. * U_SEC) // 5 sec timeout
-#define LIVES_DEFAULT_TIMEOUT  (10. * U_SEC) // 10 sec timeout
-#define LIVES_LONGER_TIMEOUT  (20. * U_SEC) // 20 sec timeout
-#define LIVES_LONGEST_TIMEOUT  (30. * U_SEC) // 30 sec timeout
+/// > 10**8 is not recommended, since we sometimes store seconds in a double
+#define TICKS_PER_SECOND_DBL ((double)100000000.)   ///< actually microseconds / 100.
+#define TICKS_PER_SECOND (int64_t)100000000 ///< ticks per second
+#define USEC_TO_TICKS (TICKS_PER_SECOND/1000000l) ///< how many TICKS in a microsecond [default 100]
 
+#define LIVES_SHORTEST_TIMEOUT  (2. * TICKS_PER_SECOND_DBL) // 2 sec timeout
+#define LIVES_SHORT_TIMEOUT  (5. * TICKS_PER_SECOND_DBL) // 5 sec timeout
+#define LIVES_DEFAULT_TIMEOUT  (10. * TICKS_PER_SECOND_DBL) // 10 sec timeout
+#define LIVES_LONGER_TIMEOUT  (20. * TICKS_PER_SECOND_DBL) // 20 sec timeout
+#define LIVES_LONGEST_TIMEOUT  (30. * TICKS_PER_SECOND_DBL) // 30 sec timeout
 
 /// rate to change pb fps when faster/slower pressed (TODO: make pref)
 #define PB_CHANGE_RATE .0005
@@ -64,7 +60,6 @@
 /// char width of start / end spinbuttons
 #define SPBWIDTHCHARS 12
 
-
 /// char width of framecounter
 #define FCWIDTHCHARS 18
 
@@ -75,8 +70,8 @@
 #define MIN_SEPWIN_HEIGHT 36
 
 /// sepwin/screen size safety margins in pixels
-#define SCR_HEIGHT_SAFETY ((int)(200.*widget_opts.scale))
 #define SCR_WIDTH_SAFETY ((int)(100.*widget_opts.scale))
+#define SCR_HEIGHT_SAFETY ((int)(200.*widget_opts.scale))
 
 /// default size for generators
 #define DEF_GEN_WIDTH 640
@@ -98,19 +93,22 @@
 #define TREE_ROW_HEIGHT ((int)(60.*widget_opts.scale))
 
 // a few GUI specific settings
-#define DEFAULT_FRAME_HSIZE ((int)(320.*widget_opts.scale))
-#define DEFAULT_FRAME_VSIZE ((int)(200.*widget_opts.scale))
+#define GUI_SCREEN_WIDTH (mainw->mgeom[widget_opts.monitor].width)
+#define GUI_SCREEN_HEIGHT (mainw->mgeom[widget_opts.monitor].height)
 
+#define SCREEN_SCALE_DEF_WIDTH 1200
+
+#define DEFAULT_FRAME_HSIZE ((int)(640.*widget_opts.scale))
+#define DEFAULT_FRAME_VSIZE ((int)(400.*widget_opts.scale))
 
 #define FRAMEBLANK_MIN_WIDTH ((int)(240.*widget_opts.scale))
-#define FRAMEBLANK_MAX_WIDTH ((int)(400.*widget_opts.scale))
+#define FRAMEBLANK_MAX_WIDTH ((int)(600.*widget_opts.scale))
 
 #define FRAMEBLANK_MIN_HEIGHT ((int)(180.*widget_opts.scale))
-#define FRAMEBLANK_MAX_HEIGHT ((int)(300.*widget_opts.scale))
+#define FRAMEBLANK_MAX_HEIGHT ((int)(400.*widget_opts.scale))
 
 #define IMSEP_MAX_HEIGHT ((int)(86.*widget_opts.scale))
-#define IMSEP_MAX_WIDTH (mainw->scr_width-20)
-
+#define IMSEP_MAX_WIDTH (GUI_SCREEN_WIDTH - 20)
 
 #define MAIN_SPIN_SPACER ((int)52.*widget_opts.scale) ///< pixel spacing for start/end spins for clip and multitrack editors
 
@@ -124,7 +122,7 @@
 #define MAX_MSG_WIDTH_CHARS ((int)(100.*widget_opts.scale)) ///< max width of text on warning/error labels
 
 /// size of the fx dialog windows scrollwindow
-#define RFX_WINSIZE_H ((int)(mainw->scr_width >= 1024 ? (820.*widget_opts.scale) : 640))
+#define RFX_WINSIZE_H ((int)(GUI_SCREEN_WIDTH >= 1024 ? (820.*widget_opts.scale) : 640))
 #define RFX_WINSIZE_V ((int)(480.*widget_opts.scale))
 
 #define DEF_BUTTON_WIDTH ((int)(80.*widget_opts.scale))
@@ -132,7 +130,7 @@
 #define DEF_DIALOG_WIDTH RFX_WINSIZE_H
 #define DEF_DIALOG_HEIGHT RFX_WINSIZE_V
 
-#define LIVES_MAIN_WINDOW_WIDGET (mainw->multitrack == NULL ? mainw->LiVES : mainw->multitrack->window)
+#define LIVES_MAIN_WINDOW_WIDGET (mainw->LiVES)
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -166,7 +164,6 @@ typedef enum {
   EXT_CNTL_MIDI = 1
 } lives_ext_cntl_t;
 
-
 /// timebase sources
 typedef enum {
   LIVES_TIME_SOURCE_NONE = 0,
@@ -175,8 +172,6 @@ typedef enum {
   LIVES_TIME_SOURCE_EXTERNAL
 } lives_time_source_t;
 
-
-
 typedef enum {
   LIVES_TOY_NONE = 0,
   LIVES_TOY_MAD_FRAMES,
@@ -184,7 +179,6 @@ typedef enum {
   LIVES_TOY_AUTOLIVES
 } lives_toy_t;
 
-
 typedef enum {
   LIVES_DIALOG_INFO,
   LIVES_DIALOG_ERROR,
@@ -195,7 +189,6 @@ typedef enum {
   LIVES_DIALOG_ABORT_CANCEL_RETRY
 } lives_dialog_t;
 
-
 /// various return conditions from rendering (multitrack or after recording)
 typedef enum {
   LIVES_RENDER_ERROR_NONE = 0,
@@ -211,7 +204,6 @@ typedef enum {
   LIVES_RENDER_ERROR_WRITE_FRAME,
 } lives_render_error_t;
 
-
 /// disk/storage status values
 typedef enum {
   LIVES_STORAGE_STATUS_UNKNOWN = 0,
@@ -221,7 +213,6 @@ typedef enum {
   LIVES_STORAGE_STATUS_OFFLINE
 } lives_storage_status_t;
 
-
 #define DVD_AUDIO_CHAN_MIN 128
 #define DVD_AUDIO_CHAN_DEFAULT 128
 #define DVD_AUDIO_CHAN_MAX 159
@@ -235,7 +226,6 @@ enum {
   LIVES_DEVICE_FW_CARD, // 5
 };
 
-
 #define THEME_DETAIL_NAME "theme_name"
 #define THEME_DETAIL_STYLE "theme_style"
 #define THEME_DETAIL_SEPWIN_IMAGE "sepwin_image"
@@ -259,7 +249,6 @@ enum {
 #define THEME_DETAIL_CE_SEL "ce_sel"
 #define THEME_DETAIL_CE_UNSEL "ce_unsel"
 
-
 /// set in set_palette_colours()
 typedef struct {
   int style;
@@ -287,7 +276,6 @@ typedef struct {
 
   // set via theme API
 
-
   LiVESWidgetColor normal_back;
   LiVESWidgetColor normal_fore;
 
@@ -336,7 +324,6 @@ enum {
   NUM_LIVES_STRING_CONSTANTS
 };
 
-
 // image types (string)
 #define LIVES_IMAGE_TYPE_JPEG "jpeg"
 #define LIVES_IMAGE_TYPE_PNG "png"
@@ -344,7 +331,6 @@ enum {
 // audio types (string)
 #define LIVES_AUDIO_TYPE_PCM "pcm"
 
-
 // file extensions
 #define LIVES_FILE_EXT_PNG "png"
 #define LIVES_FILE_EXT_JPG "jpg"
@@ -353,6 +339,7 @@ enum {
 #define LIVES_FILE_EXT_SCRAP "scrap"
 #define LIVES_FILE_EXT_TEXT "txt"
 #define LIVES_FILE_EXT_BAK "bak"
+#define LIVES_FILE_EXT_WEBM "webm"
 
 #define LIVES_FILE_EXT_BACKUP "lv1"
 #define LIVES_FILE_EXT_PROJECT "lv2"
@@ -362,14 +349,60 @@ enum {
 #define LIVES_FILE_EXT_SRT "srt"
 #define LIVES_FILE_EXT_SUB "sub"
 
+#define LIVES_FILE_EXT_PCM "pcm"
 #define LIVES_FILE_EXT_WAV "wav"
 
+#define LIVES_FILE_EXT_LAYOUT "lay"
+
+#define LIVES_FILE_EXT_RFX_SCRIPT "script"
+
+// file names
+#define CLIP_AUDIO_FILENAME "audio"
+
+#define WORKDIR_LITERAL "workdir"
+#define WORKDIR_LITERAL_LEN (strlen(WORKDIR_LITERAL))
+
+#define THEME_LITERAL "theme"
+#define THEME_SEP_IMG_LITERAL "main"
+#define THEME_FRAME_IMG_LITERAL "frame"
+#define THEME_HEADER "header.theme"
+#define THEME_HEADER_2 "header.theme_gtk2"
+
+#define LIVES_THEME_CAMERA "camera"
+
+#define LIVES_CLIP_HEADER "header.lives"
+#define LIVES_CLIP_HEADER_OLD "header"
+#define LIVES_CLIP_HEADER_OLD2 "header2"
+
+#define FX_DEFS_FILENAME "fxdefs"
+#define FX_SIZES_FILENAME "fxsizes"
+
+#define FX_DEFS_VERSIONSTRING_1_1 "LiVES filter defaults file version 1.1"
+#define FX_SIZES_VERSIONSTRING_2 "LiVES generator default sizes file version 2"
+
+#define SUBS_FILENAME "subs"
+
+#define CLIP_ORDER_FILENAME "order"
+
+#define SET_LOCK_FILENAME "lock"
+
+#define LAYOUT_MAP_FILENAME "layout.map"
+
+#define LAYOUT_NUMBERING_FILENAME "layout_numbering"
+#define LAYOUT_FILENAME "layout"
+
+// directory names
+#define LAYOUTS_DIRNAME "layouts"
+#define CLIPS_DIRNAME "clips"
+#define IMPORTS_DIRNAME "imports"
+
 // filters
 
 #define LIVES_SUBS_FILTER  {"*.srt", "*.sub", NULL}
 #define LIVES_AUDIO_LOAD_FILTER  {"*.it", "*.mp3", "*.wav", "*.ogg", "*.mod", "*.xm", "*.wma", "*.flac", NULL}
 #define LIVES_TV_CARD_TYPES  {"v4l2", "v4l", "bsdbt848", "dummy", "*autodetect", "yv12", "*", "rgb32", "rgb24", "rgb16", "rgb15", "uyvy", "yuy2", "i2420", NULL}
 
+#define NUM_VOL_LIGHTS 10
 
 typedef struct {
   double top;
@@ -378,14 +411,12 @@ typedef struct {
   double height;
 } lives_rect_t;
 
-
 typedef struct {
   char *name;
   lives_rect_t *rects; // for future use
   int z_index; // for future use
 } lives_screen_area_t;
 
-
 /// where do we add the builtin tools in the tools menu
 #define RFX_TOOL_MENU_POSN 2
 
@@ -432,6 +463,7 @@ typedef struct {
   int audio_end;
 
   boolean ext_playback; ///< using external video playback plugin
+  volatile boolean ext_audio; ///< using external video playback plugin to stream audio
   volatile boolean ext_keyboard; ///< keyboard codes must be polled from video playback plugin
 
   int ptr_x;
@@ -439,7 +471,6 @@ typedef struct {
 
   double fps_measure; ///< show fps stats after playback
 
-
   // flags
   boolean save_with_sound;
   boolean ccpd_with_sound;
@@ -496,7 +527,6 @@ typedef struct {
   // recording from an external window
   uint32_t foreign_key;
 
-
 #ifdef GUI_GTK
 #if GTK_CHECK_VERSION(3, 0, 0)
   Window foreign_id;
@@ -530,7 +560,6 @@ typedef struct {
   boolean last_transition_align_start;
   boolean last_transition_ins_frames;
 
-
   uint64_t rte; ///< current max for VJ mode == 64 effects on fg clip
 
   uint32_t last_grabbable_effect;
@@ -551,8 +580,6 @@ typedef struct {
   int pre_src_file; ///< video file we were playing before any ext input started
   int pre_src_audio_file; ///< audio file we were playing before any ext input started
 
-  int scr_width;
-  int scr_height;
   lives_toy_t toy_type;
   lives_pgid_t toy_alives_pgid; // 0, or thread for autolives toy
   boolean autolives_reset_fx;
@@ -585,10 +612,12 @@ typedef struct {
   /// for the framedraw preview - TODO use lives_framedraw_t array
   int framedraw_frame;
 
-
   /////////////////////////////////////////////////
 
   // end of static-ish info
+  int old_scr_width;
+  int old_scr_height;
+
   char first_info_file[PATH_MAX];
   boolean leave_files;
   boolean was_set;
@@ -606,7 +635,7 @@ typedef struct {
   /// and the audio 'frame' for when we are looping
   double aframeno;
 
-  // ticks are measured in 1/U_SEC of a second (by defalt a tick is 10 nano seconds)
+  // ticks are measured in 1/TICKS_PER_SECOND_DBL of a second (by defalt a tick is 10 nano seconds)
 
   // for the internal player
   double period; ///< == 1./cfile->pb_fps (unless cfile->pb_fps is 0.)
@@ -642,7 +671,6 @@ typedef struct {
   int osc_enc_height;
   float osc_enc_fps;
 
-
   /// fixed fps playback; usually fixed_fpsd==0.
   int fixed_fps_numer;
   int fixed_fps_denom;
@@ -707,7 +735,6 @@ typedef struct {
   ulong vidbar_func;
   ulong laudbar_func;
   ulong raudbar_func;
-  ulong hrule_func;
   ulong toy_func_none;
   ulong toy_func_random_frames;
   ulong toy_func_lives_tv;
@@ -727,7 +754,6 @@ typedef struct {
   // selection pointers
   ulong mouse_fn1;
   boolean mouse_blocked;
-  boolean hrule_blocked;
 
   /// stored clips
   int clipstore[FN_KEYS - 1];
@@ -776,6 +802,9 @@ typedef struct {
   LiVESWidget *recent3;
   LiVESWidget *recent4;
   LiVESWidget *save_as;
+#ifdef LIBAV_TRANSCODE
+  LiVESWidget *transcode;
+#endif
   LiVESWidget *backup;
   LiVESWidget *restore;
   LiVESWidget *save_selection;
@@ -853,6 +882,7 @@ typedef struct {
   LiVESWidget *fade_aud_in;
   LiVESWidget *fade_aud_out;
   LiVESWidget *resample_audio;
+  LiVESWidget *adj_audio_sync;
   LiVESWidget *resample_video;
   LiVESWidget *preferences;
   LiVESWidget *rename;
@@ -887,6 +917,8 @@ typedef struct {
   LiVESWidget *delete_test_rfx;
   LiVESWidget *promote_test_rfx;
 
+  LiVESWidget *vol_checkbuttons[NUM_VOL_LIGHTS][2];
+
   /// for the fileselection preview
   LiVESWidget *fs_playarea;
   LiVESWidget *fs_playalign;
@@ -911,6 +943,9 @@ typedef struct {
   LiVESWidget *spinbutton_end;
   LiVESWidget *spinbutton_start;
 
+  LiVESWidget *sa_button;
+  LiVESWidget *sa_hbox;
+
   LiVESWidget *arrow1;
   LiVESWidget *arrow2;
 
@@ -975,7 +1010,17 @@ typedef struct {
   LiVESWidget *toolbar;
   LiVESWidget *tb_hbox;
   LiVESWidget *fs1;
-  LiVESWidget *vbox1;
+  LiVESWidget *top_vbox;
+
+  LiVESWidget *l1_tb;
+  LiVESWidget *l2_tb;
+  LiVESWidget *l3_tb;
+
+  LiVESWidget *int_audio_checkbutton;
+  LiVESWidget *ext_audio_checkbutton;
+
+  ulong int_audio_func;
+  ulong ext_audio_func;
 
   LiVESWidget *volume_scale;
   LiVESWidget *vol_toolitem;
@@ -1112,6 +1157,7 @@ typedef struct {
   pthread_mutex_t fxd_active_mutex; ///< prevent simultaneous writing to active_dummy by audio and video threads
   pthread_mutex_t event_list_mutex; /// prevent simultaneous writing to event_list by audio and video threads
   pthread_mutex_t clip_list_mutex; /// prevent adding/removing to cliplist while another thread could be reading it
+  pthread_mutex_t vpp_stream_mutex; /// prevent from writing audio when stream is closing
 
   volatile lives_rfx_t *vrfx_update;
 
@@ -1176,7 +1222,6 @@ typedef struct {
   /// multi-head support
   lives_mgeometry_t *mgeom;
 
-
   /// external control inputs
   boolean ext_cntl[MAX_EXT_CNTL];
 
@@ -1201,7 +1246,6 @@ typedef struct {
 #define SPLASH_LEVEL_LOAD_RFX .8
 #define SPLASH_LEVEL_COMPLETE 1.
 
-
   boolean recoverable_layout;
 
   boolean soft_debug; ///< for testing
@@ -1327,6 +1371,8 @@ typedef struct {
   char sepimg_path[PATH_MAX];
 
   uint64_t aud_data_written;
+
+  char *dp_cache;
   ////////////////////
 } mainwindow;
 
@@ -1355,7 +1401,6 @@ extern _merge_opts *merge_opts;
 /// 0 for rfx, 1 for rte
 extern LiVESWidget *fx_dialog[2];
 
-
 #define LIVES_SIGKILL SIGKILL
 #define LIVES_SIGINT  SIGINT
 #define LIVES_SIGPIPE SIGPIPE
@@ -1366,7 +1411,6 @@ extern LiVESWidget *fx_dialog[2];
 #define LIVES_SIGTERM SIGTERM
 #define LIVES_SIGQUIT SIGQUIT
 
-
 #ifdef ENABLE_JACK
 volatile aserver_message_t jack_message;
 volatile aserver_message_t jack_message2;
