@@ -1,6 +1,6 @@
 // omc-learn.c
 // LiVES (lives-exe)
-// (c) G. Finch 2008 - 2016
+// (c) G. Finch 2008 - 2017
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -109,7 +109,7 @@ static void remove_all_nodes(boolean every, omclearn_w *omclw) {
 }
 
 
-static LIVES_INLINE int js_index(const char *string) {
+LIVES_INLINE int js_index(const char *string) {
   // js index, or midi channel number
   char **array = lives_strsplit(string, " ", -1);
   int res = atoi(array[1]);
@@ -118,7 +118,7 @@ static LIVES_INLINE int js_index(const char *string) {
 }
 
 
-static LIVES_INLINE int midi_index(const char *string) {
+LIVES_INLINE int midi_index(const char *string) {
   // midi controller number
   char **array;
   int res;
@@ -164,7 +164,7 @@ const char *get_js_filename(void) {
 boolean js_open(void) {
   if (!(prefs->omc_dev_opts & OMC_DEV_JS)) return TRUE;
 
-  if (prefs->omc_js_fname != NULL) {
+  if (strlen(prefs->omc_js_fname)) {
     js_fd = open(prefs->omc_js_fname, O_RDONLY | O_NONBLOCK);
     if (js_fd < 0) return FALSE;
   } else {
@@ -173,7 +173,7 @@ boolean js_open(void) {
       lives_snprintf(prefs->omc_js_fname, 256, "%s", tmp);
     }
   }
-  if (prefs->omc_js_fname == NULL) return FALSE;
+  if (strlen(prefs->omc_js_fname)) return FALSE;
 
   mainw->ext_cntl[EXT_CNTL_JS] = TRUE;
   d_print(_("Responding to joystick events from %s\n"), prefs->omc_js_fname);
@@ -216,7 +216,7 @@ char *js_mangle(void) {
 }
 
 
-static LIVES_INLINE int js_msg_type(const char *string) {
+LIVES_INLINE int js_msg_type(const char *string) {
   return atoi(string);
 }
 
@@ -278,7 +278,7 @@ boolean midi_open(void) {
 #endif
 
 #ifndef IS_MINGW
-    if (prefs->omc_midi_fname != NULL) {
+    if (strlen(prefs->omc_midi_fname)) {
       midi_fd = open(prefs->omc_midi_fname, O_RDONLY | O_NONBLOCK);
       if (midi_fd < 0) return FALSE;
     } else {
@@ -287,7 +287,7 @@ boolean midi_open(void) {
         lives_snprintf(prefs->omc_midi_fname, 256, "%s", tmp);
       }
     }
-    if (prefs->omc_midi_fname == NULL) return FALSE;
+    if (!strlen(prefs->omc_midi_fname)) return FALSE;
 
     d_print(_("Responding to MIDI events from %s\n"), prefs->omc_midi_fname);
 #endif
@@ -480,7 +480,7 @@ char *midi_mangle(void) {
 #endif //OMC_MIDI_IMPL
 
 
-static LIVES_INLINE char *cut_string_elems(const char *string, int nelems) {
+LIVES_INLINE char *cut_string_elems(const char *string, int nelems) {
   // remove elements after nelems
 
   char *retval = lives_strdup(string);
@@ -1232,21 +1232,15 @@ static void close_learner_dialog(LiVESButton *button, livespointer user_data) {
 static omclearn_w *create_omclearn_dialog(void) {
   LiVESWidget *ok_button;
   LiVESWidget *scrolledwindow;
-  int winsize_h, scr_width = mainw->scr_width;
-  int winsize_v, scr_height = mainw->scr_height;
+  int winsize_h, winsize_v;
 
   omclearn_w *omclw = (omclearn_w *)lives_malloc(sizeof(omclearn_w));
 
   omclw->tbl_rows = 4;
   omclw->tbl_currow = -1;
 
-  if (prefs->gui_monitor != 0) {
-    scr_width = mainw->mgeom[prefs->gui_monitor - 1].width;
-    scr_height = mainw->mgeom[prefs->gui_monitor - 1].height;
-  }
-
-  winsize_h = scr_width - SCR_WIDTH_SAFETY;
-  winsize_v = scr_height - SCR_HEIGHT_SAFETY;
+  winsize_h = GUI_SCREEN_WIDTH - SCR_WIDTH_SAFETY;
+  winsize_v = GUI_SCREEN_HEIGHT - SCR_HEIGHT_SAFETY;
 
   omclw->dialog = lives_standard_dialog_new(_("OMC Learner"), FALSE, winsize_h, winsize_v);
   lives_signal_handlers_disconnect_by_func(omclw->dialog, return_true, NULL);
@@ -1261,7 +1255,7 @@ static omclearn_w *create_omclearn_dialog(void) {
 
   lives_box_pack_start(LIVES_BOX(omclw->top_vbox), scrolledwindow, TRUE, TRUE, 0);
 
-  omclw->clear_button = lives_button_new_from_stock(LIVES_STOCK_CLEAR, _("Clear _unmatched"));
+  omclw->clear_button = lives_standard_button_new_from_stock(LIVES_STOCK_CLEAR, _("Clear _unmatched"));
   lives_widget_set_size_request(omclw->clear_button, DEF_BUTTON_WIDTH * 4, -1);
   lives_container_set_border_width(LIVES_CONTAINER(omclw->clear_button), widget_opts.border_width);
 
@@ -1273,7 +1267,7 @@ static omclearn_w *create_omclearn_dialog(void) {
 
   lives_widget_set_sensitive(omclw->clear_button, FALSE);
 
-  omclw->del_all_button = lives_button_new_from_stock(LIVES_STOCK_DELETE, _("_Delete all"));
+  omclw->del_all_button = lives_standard_button_new_from_stock(LIVES_STOCK_DELETE, _("_Delete all"));
   lives_widget_set_size_request(omclw->del_all_button, DEF_BUTTON_WIDTH * 4, -1);
   lives_container_set_border_width(LIVES_CONTAINER(omclw->del_all_button), widget_opts.border_width);
 
@@ -1285,7 +1279,7 @@ static omclearn_w *create_omclearn_dialog(void) {
 
   lives_widget_set_sensitive(omclw->del_all_button, FALSE);
 
-  ok_button = lives_button_new_from_stock(LIVES_STOCK_CLOSE, _("_Close Window"));
+  ok_button = lives_standard_button_new_from_stock(LIVES_STOCK_CLOSE, _("_Close Window"));
   lives_widget_set_size_request(ok_button, DEF_BUTTON_WIDTH * 4, -1);
   lives_container_set_border_width(LIVES_CONTAINER(ok_button), widget_opts.border_width);
 
@@ -1293,22 +1287,18 @@ static omclearn_w *create_omclearn_dialog(void) {
 
   lives_widget_set_can_focus_and_default(ok_button);
 
-  lives_widget_grab_default(ok_button);
+  lives_widget_grab_default_special(ok_button);
 
   lives_signal_connect(LIVES_GUI_OBJECT(ok_button), LIVES_WIDGET_CLICKED_SIGNAL,
                        LIVES_GUI_CALLBACK(close_learner_dialog),
                        NULL);
 
   if (prefs->gui_monitor != 0) {
-    int xcen = mainw->mgeom[prefs->gui_monitor - 1].x + (mainw->mgeom[prefs->gui_monitor - 1].width
-               - lives_widget_get_allocation_width(omclw->dialog)) / 2;
-    int ycen = mainw->mgeom[prefs->gui_monitor - 1].y + (mainw->mgeom[prefs->gui_monitor - 1].height
-               - lives_widget_get_allocation_height(omclw->dialog)) / 2;
-    lives_window_set_screen(LIVES_WINDOW(omclw->dialog), mainw->mgeom[prefs->gui_monitor - 1].screen);
-    lives_window_move(LIVES_WINDOW(omclw->dialog), xcen, ycen);
+    lives_window_center(LIVES_WINDOW(omclw->dialog));
   }
 
   if (prefs->open_maximised) {
+    lives_window_unmaximize(LIVES_WINDOW(omclw->dialog));
     lives_window_maximize(LIVES_WINDOW(omclw->dialog));
   }
 
@@ -1662,8 +1652,8 @@ static lives_omc_match_node_t *omc_match_sig(int type, int index, const char *si
   return NULL;
   }*/
 
-
-static LIVES_INLINE int omclearn_get_fixed_elems(const char *string1, const char *string2) {
+/*
+LIVES_INLINE int omclearn_get_fixed_elems(const char *string1, const char *string2) {
   // count how many (non-space) elements match
   // e.g "a b c" and "a b d" returns 2
 
@@ -1681,9 +1671,9 @@ static LIVES_INLINE int omclearn_get_fixed_elems(const char *string1, const char
 
   return match + 1;
 }
+*/
 
-
-static LIVES_INLINE int get_nth_elem(const char *string, int idx) {
+LIVES_INLINE int get_nth_elem(const char *string, int idx) {
   char **array = lives_strsplit(string, " ", -1);
   int retval = atoi(array[idx]);
   lives_strfreev(array);
