@@ -46,6 +46,11 @@ void init_special(void) {
 }
 
 
+const lives_special_aspect_t *paramspecial_get_aspect() {
+  return &aspect;
+}
+
+
 void add_to_special(const char *sp_string, lives_rfx_t *rfx) {
   char **array = lives_strsplit(sp_string, "|", -1);
   int num_widgets = get_token_count(sp_string, '|') - 2;
@@ -247,19 +252,17 @@ void check_for_special(lives_rfx_t *rfx, lives_param_t *param, LiVESBox *pbox) {
       box = lives_hbox_new(FALSE, 0);
       lives_box_pack_start(LIVES_BOX(LIVES_WIDGET(pbox)), box, FALSE, FALSE, widget_opts.packing_height * 2);
 
-      add_fill_to_box(LIVES_BOX(box));
-
-      checkbutton = lives_standard_check_button_new((tmp = lives_strdup(_("Maintain _Aspect Ratio"))), TRUE,
-                    LIVES_BOX(box), (tmp2 = lives_strdup(_("Maintain aspect ratio of original frame"))));
+      aspect.checkbutton = lives_standard_check_button_new((tmp = lives_strdup(_("Maintain _Aspect Ratio"))), TRUE,
+                           LIVES_BOX(box), (tmp2 = lives_strdup(_("Maintain aspect ratio of original frame"))));
 
       lives_free(tmp);
       lives_free(tmp2);
 
+      aspect.label = widget_opts.last_label;
+
       add_fill_to_box(LIVES_BOX(box));
 
       lives_widget_show_all(box);
-
-      aspect.checkbutton = checkbutton;
     }
   }
 
