@@ -1,6 +1,6 @@
 // preferences.h
 // LiVES (lives-exe)
-// (c) G. Finch (salsaman@gmail.com) 2004 - 2016
+// (c) G. Finch (salsaman_lives@gmail.com) 2004 - 2017
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -16,6 +16,7 @@
 #define PREFS_COLOURS_CHANGED (1<<3)
 #define PREFS_XCOLOURS_CHANGED (1<<4)
 #define PREFS_IMAGES_CHANGED (1<<5)
+#define PREFS_MONITOR_CHANGED (1<<6)
 
 #define PULSE_AUDIO_URL "http://www.pulseaudio.org"
 #define JACK_URL "http://jackaudio.org"
@@ -50,8 +51,6 @@ typedef struct {
 #define AUDIO_PLAYER_MPLAYER "mplayer"
 #define AUDIO_PLAYER_MPLAYER2 "mplayer2"
 
-
-
   char aplayer[512]; // name, eg. "jack","pulse","sox","mplayer","mplayer2"
 
   /// frame quantisation type
@@ -72,7 +71,6 @@ typedef struct {
   char prefix_dir[PATH_MAX];
   char lib_dir[PATH_MAX];
 
-
   char image_ext[16];
 
   uint32_t warning_mask;
@@ -146,7 +144,7 @@ typedef struct {
 #define SEPWIN_TYPE_STICKY 1
 
   boolean show_player_stats;
-  boolean show_framecount;
+  //  boolean show_framecount; - use hide_framebar
   boolean show_subtitles;
   boolean loop_recording;
   boolean discard_tv;
@@ -160,7 +158,6 @@ typedef struct {
 #define REC_AUDIO (1<<4)
 #define REC_AFTER_PB (1<<5)
 
-
   int audio_src;
 #define AUDIO_SRC_INT 0
 #define AUDIO_SRC_EXT 1
@@ -292,8 +289,6 @@ typedef struct {
 
   boolean ce_maxspect;
 
-  boolean show_button_icons;
-
   boolean lamp_buttons;
 
   boolean autoload_subs;
@@ -324,14 +319,12 @@ typedef struct {
   /** default 0; 1==use old (bad) behaviour on bigendian machines (r/w bigend ints/doubles); 2==bad reads, good writes */
   int bigendbug;
 
-
   // these are defualt values; actual values can be adjusted in Preferences
 #define DEF_DS_WARN_LEVEL 250000000  // 250MB
   uint64_t ds_warn_level; ///< diskspace warn level bytes
 #define DEF_DS_CRIT_LEVEL 20000000 // 20MB
   uint64_t ds_crit_level; ///< diskspace critical level bytes
 
-
 #define LIVES_CDISK_LEAVE_ORPHAN_SETS (1<<0)
 #define LIVES_CDISK_LEAVE_BFILES (1<<1)
 #define LIVES_CDISK_REMOVE_ORPHAN_LAYOUTS (1<<2)
@@ -341,7 +334,6 @@ typedef struct {
 #define LIVES_CDISK_REMOVE_LOCK_FILES (1<<5) ///< not yet implemented - TODO
 #define LIVES_CDISK_REBUILD_ORDER_FILES (1<<6) ///< not yet implemented - TODO
 
-
   uint32_t clear_disk_opts;
 
 #ifdef HAVE_YUV4MPEG
@@ -372,6 +364,14 @@ typedef struct {
   int max_disp_vtracks;
 
   boolean mt_load_fuzzy;
+
+  boolean hide_framebar;
+
+  boolean hfbwnp;
+
+  boolean show_asrc;
+
+  float ahold_threshold;
 } _prefs;
 
 enum {
@@ -398,9 +398,8 @@ enum {
   N_COLUMNS
 };
 
-
-#define PREFWIN_WIDTH (mainw->scr_width*.9)
-#define PREFWIN_HEIGHT (mainw->scr_height*.9)
+#define PREFWIN_WIDTH (GUI_SCREEN_WIDTH * .9)
+#define PREFWIN_HEIGHT (GUI_SCREEN_HEIGHT * .9)
 
 #define DS_WARN_CRIT_MAX 1000000. ///< MB.
 
@@ -550,6 +549,7 @@ typedef struct {
   LiVESWidget *checkbutton_start_ajack;
   LiVESWidget *checkbutton_afollow;
   LiVESWidget *checkbutton_aclips;
+  LiVESWidget *spinbutton_ext_aud_thresh;
   LiVESWidget *spinbutton_mt_def_width;
   LiVESWidget *spinbutton_mt_def_height;
   LiVESWidget *spinbutton_mt_def_fps;
@@ -572,6 +572,8 @@ typedef struct {
   LiVESWidget *checkbutton_auto_trim;
   LiVESWidget *checkbutton_nobord;
   LiVESWidget *checkbutton_concat_images;
+  LiVESWidget *checkbutton_show_asrc;
+  LiVESWidget *checkbutton_hfbwnp;
   LiVESWidget *forcesmon;
   LiVESWidget *forcesmon_hbox;
   LiVESList *pbq_list;
@@ -639,7 +641,6 @@ typedef struct {
 
   int nfx_threads;
 
-
   LiVESList *disabled_decoders;
   LiVESList *disabled_decoders_new;
 } _future_prefs;
@@ -678,10 +679,9 @@ void pref_change_images(void);
 void pref_change_xcolours(void);
 void pref_change_colours(void);
 
-
 void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 
-
+// NOTE: the following definitions must match with equivalent keys in smogrify
 // factories (pseudo prefs), called from cpp binding
 
 #define PREF_REC_EXT_AUDIO "rec_ext_audio"
@@ -689,7 +689,9 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 #define PREF_SEPWIN_STICKY "sepwin_sticky"
 #define PREF_MT_EXIT_RENDER "mt_exit_render"
 
-
+// factories non-cpp
+#define PREF_SHOW_ASRC "show_audio_src"
+#define PREF_HFBWNP "hide_framebar_when_not_playing"
 
 // normal prefs
 
@@ -731,7 +733,6 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 #define PREF_CURRENT_AUTOTRANS "current_autotrans"
 #define PREF_DEF_AUTOTRANS "def_autotrans"  // readonly
 
-
 ////////////////////// utf8 values
 
 #define PREF_OMC_MIDI_FNAME "omc_midi_fname"
@@ -750,12 +751,10 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 #define PREF_RECENT3 "recent3"
 #define PREF_RECENT4 "recent4"
 
-
 /////////////////// integer64 values
 #define PREF_DS_WARN_LEVEL "ds_warn_level"
 #define PREF_DS_CRIT_LEVEL "ds_crit_level"
 
-
 /////////////////// integer32 values
 #define PREF_STARTUP_PHASE "startup_phase"
 
@@ -806,7 +805,6 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 
 #define PREF_DL_BANDWIDTH_K "dl_bandwidth_K"
 
-
 ////////// boolean values
 #define PREF_SHOW_RECENT_FILES "show_recent_files"
 #define PREF_FORCE_SINGLE_MONITOR "force_single_monitor"
@@ -837,33 +835,28 @@ void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
 #define PREF_SAVE_DIRECTORIES "save_directories"
 #define PREF_CONSERVE_SPACE "conserve_space"
 
-
-
 ////////// double values
 #define PREF_MT_DEF_FPS "mt_def_fps"
 
 #define PREF_DEFAULT_FPS "default_fps"
 
-
+///////// float values
+#define PREF_AHOLD_THRESHOLD "ahold_threshold"
 
 ////////// list values
 #define PREF_DISABLED_DECODERS "disabled_decoders"
 
-
-
 // defaults (readonly)
 /////////////// string values
 #define PREF_SOX_COMMAND "sox_command"
 #define PREF_MPLAYER_AUDIO_COMMAND "mplayer_audio_command"
 #define PREF_MPLAYER2_AUDIO_COMMAND "mplayer2_audio_command"
 
-
-
 void pref_factory_bool(const char *prefidx, boolean newval);
 void pref_factory_int(const char *prefidx, int newval);
+void pref_factory_float(const char *prefidx, float newval);
 void pref_factory_bitmapped(const char *prefidx, int bitfield, boolean newval);
 
-
 int get_pref(const char *key, char *val, int maxlen);
 int get_pref_from_file(const char *filename, const char *key, char *val, int maxlen);
 int get_pref_utf8(const char *key, char *val, int maxlen);
@@ -896,5 +889,4 @@ void set_palette_prefs(void);
 
 boolean lives_ask_permission(int what);
 
-
 #endif
