@@ -72,13 +72,13 @@ boolean lives_pulse_init(short startup_phase) {
 
   pa_state = pa_context_get_state(pcon);
 
-  stime = lives_get_current_ticks();
+  stime = lives_get_current_ticks(0, 0);
 
   while (pa_state != PA_CONTEXT_READY && ntime < LIVES_SHORT_TIMEOUT) {
     lives_usleep(prefs->sleep_time);
     sched_yield();
     pa_state = pa_context_get_state(pcon);
-    ntime = lives_get_current_ticks() - stime;
+    ntime = lives_get_current_ticks(0, 0) - stime;
   }
 
   if (ntime >= LIVES_SHORT_TIMEOUT) {
@@ -159,7 +159,15 @@ static void sample_silence_pulse(pulse_driver_t *pdriver, size_t nbytes, size_t
     if (nbytes < xbytes) xbytes = nbytes;
     buff = (uint8_t *)lives_try_malloc0(xbytes);
     if (!buff) return;
-    if (pdriver->astream_fd != -1) audio_stream(buff, xbytes, pdriver->astream_fd);
+    if (pdriver->astream_fd != -1) audio_stream(buff, xbytes, pdriver->astream_fd); // old streaming API
+
+    // new streaming API
+    if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL && pdriver->playing_file != -1
+        && pdriver->playing_file != mainw->ascrap_file) {
+      int nframes = nbytes / pdriver->out_achans / (pdriver->out_asamps >> 3);
+      sample_silence_stream(pdriver->out_achans, nframes);
+    }
+
     if (mainw->audio_frame_buffer != NULL && prefs->audio_src != AUDIO_SRC_EXT) {
       pthread_mutex_lock(&mainw->abuf_frame_mutex);
       append_to_audio_buffer16(mainw->audio_frame_buffer, buff, xbytes / 2, 0);
@@ -228,9 +236,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
     case ASERVER_CMD_FILE_OPEN:
       new_file = atoi((char *)msg->data);
       if (pulsed->playing_file != new_file) {
-        if (pulsed->is_opening) filename = lives_build_filename(prefs->workdir, mainw->files[new_file]->handle,
-                                             "audiodump.pcm", NULL);
-        else filename = lives_build_filename(prefs->workdir, mainw->files[new_file]->handle, "audio", NULL);
+        filename = lives_get_audio_file_name(new_file);
         pulsed->fd = lives_open2(filename, O_RDONLY);
         if (pulsed->fd == -1) {
           // dont show gui errors - we are running in realtime thread
@@ -238,6 +244,11 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
           LIVES_ERROR(filename);
           pulsed->playing_file = -1;
         } else {
+#ifdef HAVE_POSIX_FADVISE
+          if (new_file == mainw->ascrap_file) {
+            posix_fadvise(pulsed->fd, 0, 0, POSIX_FADV_SEQUENTIAL);
+          }
+#endif
           pulsed->seek_pos = 0;
           pulsed->playing_file = new_file;
           pulsed->audio_ticks = mainw->currticks;
@@ -327,9 +338,10 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
 
       } else {
         if (LIVES_LIKELY(pulsed->fd >= 0)) {
-          if ((pulsed->playing_file == mainw->ascrap_file && !mainw->preview) && mainw->playing_file >= -1
-              && mainw->files[mainw->playing_file]->achans > 0) {
-            xfile = mainw->files[mainw->playing_file];
+          int playfile = mainw->playing_file;
+          if ((pulsed->playing_file == mainw->ascrap_file && !mainw->preview) && playfile >= -1
+              && mainw->files[playfile] != NULL && mainw->files[playfile]->achans > 0) {
+            xfile = mainw->files[playfile];
           }
 
           pulsed->aPlayPtr->size = 0;
@@ -399,7 +411,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
                   if (((((mainw->agen_key == 0 && !mainw->agen_needs_reinit) || mainw->multitrack != NULL) &&
                         (pulsed->aPlayPtr->size = read(pulsed->fd, pulsed->aPlayPtr->data, in_bytes)) == 0)) ||
                       (((mainw->agen_key != 0 || mainw->agen_needs_reinit) && mainw->multitrack == NULL &&
-                        pulsed->seek_pos + in_bytes >= xfile->afilesize))) {
+                        (xfile != NULL && pulsed->seek_pos + in_bytes >= xfile->afilesize)))) {
                     if (*pulsed->whentostop == STOP_ON_AUD_END) {
                       *pulsed->cancelled = CANCEL_AUD_END;
                     } else {
@@ -510,7 +522,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
             }
           }
 
-          if (has_audio_filters(AF_TYPE_ANY) && (pulsed->playing_file != mainw->ascrap_file)) {
+          if ((has_audio_filters(AF_TYPE_ANY) || mainw->ext_audio) && (pulsed->playing_file != mainw->ascrap_file)) {
             boolean memok = TRUE;
             float **fltbuf = (float **)lives_malloc(pulsed->out_achans * sizeof(float *));
             register int i;
@@ -522,22 +534,30 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
               if (fltbuf[i] == NULL) {
                 memok = FALSE;
                 for (--i; i >= 0; i--) {
-                  lives_free(fltbuf[i]);
+                  lives_freep((void **)&fltbuf[i]);
                 }
                 break;
               }
 
-              sample_move_d16_float(fltbuf[i], (short *)pulsed->sound_buffer + i, numFramesToWrite, pulsed->out_achans, FALSE, FALSE, 1.0);
+              pulsed->abs_maxvol_heard = sample_move_d16_float(fltbuf[i], (short *)pulsed->sound_buffer + i, numFramesToWrite, pulsed->out_achans, FALSE,
+                                         FALSE, 1.0);
             }
 
             if (memok) {
-              int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->out_arate * U_SEC);
+              int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->out_arate * TICKS_PER_SECOND_DBL);
               // apply any audio effects with in_channels
 
-              weed_apply_audio_effects_rt(fltbuf, pulsed->out_achans, numFramesToWrite, pulsed->out_arate, tc, FALSE);
+              if (has_audio_filters(AF_TYPE_ANY)) weed_apply_audio_effects_rt(fltbuf, pulsed->out_achans, numFramesToWrite, pulsed->out_arate, tc, FALSE);
+
+              // new streaming API
+              pthread_mutex_lock(&mainw->vpp_stream_mutex);
+              if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+                (*mainw->vpp->render_audio_frame_float)(fltbuf, numFramesToWrite);
+              }
+              pthread_mutex_unlock(&mainw->vpp_stream_mutex);
 
               // convert float audio back to s16
-              sample_move_float_int(pulsed->sound_buffer, fltbuf, numFramesToWrite, 1.0, pulsed->out_achans, 16, 0,
+              sample_move_float_int(pulsed->sound_buffer, fltbuf, numFramesToWrite, 1.0, pulsed->out_achans, PA_SAMPSIZE, 0,
                                     (capable->byte_order == LIVES_LITTLE_ENDIAN), FALSE, 1.0);
 
               for (i = 0; i < pulsed->out_achans; i++) {
@@ -585,7 +605,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
             pulsed->sound_buffer = (uint8_t *)pulsed->aPlayPtr->data;
             buf = (void *)pulsed->sound_buffer;
 
-            if (has_audio_filters(AF_TYPE_ANY)) {
+            if (has_audio_filters(AF_TYPE_ANY) || mainw->ext_audio) {
               register int i;
 
               memok = TRUE;
@@ -607,13 +627,20 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
               }
 
               if (memok) {
-                int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->out_arate * U_SEC);
+                int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->out_arate * TICKS_PER_SECOND_DBL);
                 // apply any audio effects with in_channels
 
-                weed_apply_audio_effects_rt(fp, pulsed->out_achans, numFramesToWrite, pulsed->out_arate, tc, FALSE);
+                if (has_audio_filters(AF_TYPE_ANY)) weed_apply_audio_effects_rt(fp, pulsed->out_achans, numFramesToWrite, pulsed->out_arate, tc, FALSE);
+
+                // new streaming API
+                pthread_mutex_lock(&mainw->vpp_stream_mutex);
+                if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+                  (*mainw->vpp->render_audio_frame_float)(fp, numFramesToWrite);
+                }
+                pthread_mutex_unlock(&mainw->vpp_stream_mutex);
 
                 // convert float audio to s16
-                sample_move_float_int(buf, fp, numFramesToWrite, 1.0, pulsed->out_achans, 16, FALSE,
+                sample_move_float_int(buf, fp, numFramesToWrite, 1.0, pulsed->out_achans, PA_SAMPSIZE, FALSE,
                                       (capable->byte_order == LIVES_LITTLE_ENDIAN), FALSE, 1.0);
 
                 for (i = 0; i < pulsed->out_achans; i++) {
@@ -628,7 +655,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
                 fp[i] = fbuffer + (i * numFramesToWrite);
               }
               sample_move_float_int(buf, fp, numFramesToWrite, 1.0,
-                                    pulsed->out_achans, 16, 0, (capable->byte_order == LIVES_LITTLE_ENDIAN), FALSE, 1.0);
+                                    pulsed->out_achans, PA_SAMPSIZE, 0, (capable->byte_order == LIVES_LITTLE_ENDIAN), FALSE, 1.0);
             }
 
             lives_freep((void **)&fbuffer);
@@ -638,7 +665,7 @@ static void pulse_audio_write_process(pa_stream *pstream, size_t nbytes, void *a
               // write generated audio to ascrap_file
               size_t rbytes = numFramesToWrite * mainw->files[mainw->ascrap_file]->achans *
                               mainw->files[mainw->ascrap_file]->asampsize >> 3;
-              //pulse_flush_read_data(pulsed, mainw->ascrap_file, nbytes, mainw->files[mainw->ascrap_file]->signed_endian & AFORM_BIG_ENDIAN, buf);
+              pulse_flush_read_data(pulsed, mainw->ascrap_file, nbytes, mainw->files[mainw->ascrap_file]->signed_endian & AFORM_BIG_ENDIAN, buf);
               mainw->files[mainw->ascrap_file]->aseek_pos += rbytes;
             }
           }
@@ -748,7 +775,6 @@ size_t pulse_flush_read_data(pulse_driver_t *pulsed, int fileno, size_t rbytes,
 
   lives_clip_t *ofile;
 
-  return 0;
   if (mainw->agen_key == 0 && !mainw->agen_needs_reinit) {
     if (prb == 0 || mainw->rec_samples == 0) return 0;
     if (prb <= PULSE_READ_BYTES * 2 && rbytes > 0) {
@@ -835,11 +861,13 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
   void *data;
   size_t rbytes = nbytes;
 
-  if (!pulsed->in_use) return;
-
-  if (mainw->playing_file < 0 && prefs->audio_src == AUDIO_SRC_EXT) return;
-
-  if (mainw->effects_paused) return; // pause during record ???
+  if (!pulsed->in_use || (mainw->playing_file < 0 && prefs->audio_src == AUDIO_SRC_EXT) || mainw->effects_paused) {
+    if (pulsed->playing_file == -1 && prefs->audio_src == AUDIO_SRC_INT) {
+      pa_operation *paop = pa_stream_cork(pstream, 1, NULL, NULL);
+      pa_operation_unref(paop);
+    }
+    return;
+  }
 
   pa_stream_peek(pulsed->pstream, (const void **)&data, &rbytes);
 
@@ -866,8 +894,10 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
 
     // in this case we read external audio, but maybe not record it
     // we may wish to analyse the audio for example, or push it to a video generator
+    // or stream it to the video playback plugin
 
-    if (has_audio_filters(AF_TYPE_A)) {
+    if ((prefs->audio_src == AUDIO_SRC_EXT && !mainw->video_seek_ready && prefs->ahold_threshold > pulsed->abs_maxvol_heard)
+        || has_audio_filters(AF_TYPE_A) || mainw->ext_audio) {
       // convert to float, apply any analysers
       boolean memok = TRUE;
       float **fltbuf = (float **)lives_malloc(pulsed->in_achans * sizeof(float *));
@@ -875,6 +905,8 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
 
       size_t xnframes = (size_t)(rbytes / (pulsed->in_asamps >> 3) / pulsed->in_achans);
 
+      if (fltbuf == NULL) return;
+
       for (i = 0; i < pulsed->in_achans; i++) {
         // convert s16 to non-interleaved float
         fltbuf[i] = (float *)lives_try_malloc(xnframes * sizeof(float));
@@ -886,7 +918,7 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
           break;
         }
 
-        sample_move_d16_float(fltbuf[i], (short *)data + i, xnframes, pulsed->in_achans, FALSE, FALSE, 1.0);
+        pulsed->abs_maxvol_heard = sample_move_d16_float(fltbuf[i], (short *)(data) + i, xnframes, pulsed->in_achans, FALSE, FALSE, 1.0);
 
         if (mainw->audio_frame_buffer != NULL && prefs->audio_src == AUDIO_SRC_EXT) {
           // if we have audio triggered gens., push audio to it
@@ -898,23 +930,30 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
       }
 
       if (memok) {
-        int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->in_arate * U_SEC);
+        int64_t tc = pulsed->audio_ticks + (int64_t)(pulsed->frames_written / (double)pulsed->in_arate * TICKS_PER_SECOND_DBL);
         // apply any audio effects with in channels but no out channels
 
-        weed_apply_audio_effects_rt(fltbuf, pulsed->in_achans, xnframes, pulsed->in_arate, tc, TRUE);
+        if (has_audio_filters(AF_TYPE_A)) weed_apply_audio_effects_rt(fltbuf, pulsed->in_achans, xnframes, pulsed->in_arate, tc, TRUE);
 
+        // new streaming API
+        pthread_mutex_lock(&mainw->vpp_stream_mutex);
+        if (mainw->ext_audio && mainw->vpp != NULL && mainw->vpp->render_audio_frame_float != NULL) {
+          (*mainw->vpp->render_audio_frame_float)(fltbuf, xnframes);
+        }
+        pthread_mutex_unlock(&mainw->vpp_stream_mutex);
         for (i = 0; i < pulsed->in_achans; i++) {
           lives_free(fltbuf[i]);
         }
       }
 
-      lives_free(fltbuf);
+      lives_freep((void **)&fltbuf);
     }
   }
 
   if (pulsed->playing_file == -1 || (mainw->record && mainw->record_paused)) {
     pa_stream_drop(pulsed->pstream);
     if (pulsed->playing_file == -1) {
+      // This is NECESSARY to reduce / eliminate huge latencies.
       pa_operation *paop = pa_stream_flush(pulsed->pstream, NULL, NULL); // if not recording, flush the rest of audio (to reduce latency)
       pa_operation_unref(paop);
     }
@@ -922,7 +961,7 @@ static void pulse_audio_read_process(pa_stream *pstream, size_t nbytes, void *ar
   }
 
   if (mainw->playing_file != mainw->ascrap_file) {
-    if (mainw->playing_file != -1) mainw->files[mainw->playing_file]->aseek_pos += rbytes;
+    if IS_VALID_CLIP(mainw->playing_file) mainw->files[mainw->playing_file]->aseek_pos += rbytes;
     if (mainw->ascrap_file != -1 && !mainw->record_paused) mainw->files[mainw->ascrap_file]->aseek_pos += rbytes;
   } else if (mainw->ascrap_file != -1 && !mainw->record_paused) mainw->files[mainw->ascrap_file]->aseek_pos += rbytes;
 
@@ -991,15 +1030,16 @@ int pulse_audio_init(void) {
   pulsed.num_calls = 0;
   pulsed.chunk_size = 0;
   pulsed.astream_fd = -1;
+  pulsed.abs_maxvol_heard = 0.;
+  pulsed.waitforop = FALSE;
   pulsed.pulsed_died = FALSE;
   pulsed.aPlayPtr = (audio_buffer_t *)lives_malloc(sizeof(audio_buffer_t));
   pulsed.aPlayPtr->data = NULL;
   pulsed.aPlayPtr->size = 0;
   pulsed.aPlayPtr->max_size = 0;
-  gettimeofday(&pulsed.last_reconnect_attempt, 0);
-  pulsed.in_achans = 2;
-  pulsed.out_achans = 2;
-  pulsed.out_asamps = 16;
+  pulsed.in_achans = PA_ACHANS;
+  pulsed.out_achans = PA_ACHANS;
+  pulsed.out_asamps = PA_SAMPSIZE;
   pulsed.mute = FALSE;
   pulsed.out_chans_available = PULSE_MAX_OUTPUT_CHANS;
   pulsed.is_output = TRUE;
@@ -1029,10 +1069,11 @@ int pulse_audio_read_init(void) {
   pulsed_reader.num_calls = 0;
   pulsed_reader.chunk_size = 0;
   pulsed_reader.astream_fd = -1;
+  pulsed_reader.abs_maxvol_heard = 0.;
+  pulsed_reader.waitforop = FALSE;
   pulsed_reader.pulsed_died = FALSE;
-  gettimeofday(&pulsed_reader.last_reconnect_attempt, 0);
-  pulsed_reader.in_achans = 2;
-  pulsed_reader.in_asamps = 16;
+  pulsed_reader.in_achans = PA_ACHANS;
+  pulsed_reader.in_asamps = PA_SAMPSIZE;
   pulsed_reader.mute = FALSE;
   pulsed_reader.is_output = FALSE;
   pulsed_reader.is_paused = FALSE;
@@ -1085,6 +1126,8 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
   pa_proplist_sets(pdriver->pa_props, PA_PROP_APPLICATION_PROCESS_ID, mypid);
   pa_proplist_sets(pdriver->pa_props, PA_PROP_APPLICATION_VERSION, LiVES_VERSION);
 
+  lives_free(mypid);
+
 #ifdef GUI_GTK
   pa_proplist_sets(pdriver->pa_props, PA_PROP_APPLICATION_LANGUAGE, pango_language_to_string(gtk_get_default_language()));
 #endif
@@ -1100,7 +1143,7 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
 
   pa_spec.channels = pdriver->out_achans = pdriver->in_achans;
 
-  pdriver->in_asamps = pdriver->out_asamps = 16;
+  pdriver->in_asamps = pdriver->out_asamps = PA_SAMPSIZE;
   pdriver->out_signed = 0;
 
   if (capable->byte_order == LIVES_BIG_ENDIAN) pdriver->out_endian = AFORM_BIG_ENDIAN;
@@ -1164,6 +1207,7 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
     pdriver->frames_written = 0;
     pdriver->usec_start = 0;
     pdriver->in_use = FALSE;
+    pdriver->abs_maxvol_heard = 0.;
     prb = 0;
 
     pa_stream_set_read_callback(pdriver->pstream, pulse_audio_read_process, pdriver);
@@ -1177,13 +1221,37 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
 
   }
 
-  lives_free(mypid);
-
   return 0;
 }
 
 
+
+static void paop_done(pa_stream *s, int success, void *userdata) {
+  pulse_driver_t *pdriver = (pulse_driver_t *)userdata;
+  pdriver->waitforop = FALSE;
+}
+
+
 void pulse_driver_uncork(pulse_driver_t *pdriver) {
+  int alarm_handle;
+  pa_operation *paop;
+
+  pdriver->abs_maxvol_heard = 0.;
+
+  pdriver->waitforop = TRUE;
+
+  alarm_handle = lives_alarm_set(LIVES_SHORTEST_TIMEOUT);
+
+  paop = pa_stream_flush(pdriver->pstream, paop_done, pdriver);
+
+  while (!pdriver->waitforop && !lives_alarm_get(alarm_handle)) {
+    lives_usleep(prefs->sleep_time);
+  }
+
+  lives_alarm_clear(alarm_handle);
+
+  pa_operation_unref(paop);
+
   pa_stream_cork(pdriver->pstream, 0, NULL, NULL);
 }
 
@@ -1230,11 +1298,12 @@ int64_t lives_pulse_get_time(pulse_driver_t *pulsed, boolean absolute) {
   {
     pa_usec_t usec;
     pa_stream_get_time(pulsed->pstream, &usec);
-    return pulsed->audio_ticks * absolute + (int64_t)((usec - pulsed->usec_start) * U_SEC_RATIO);
+    return pulsed->audio_ticks * absolute + (int64_t)((usec - pulsed->usec_start) * USEC_TO_TICKS);
   }
 #else
-  if (pulsed->is_output) xtime = pulsed->audio_ticks * absolute + (int64_t)(frames_written / (double)pulsed->out_arate * U_SEC);
-  else xtime = pulsed->audio_ticks * absolute + (int64_t)(frames_written / (double)afile->arate * U_SEC);
+  if (pulsed->is_output) xtime = pulsed->audio_ticks * absolute + (int64_t)(frames_written / (double)pulsed->out_arate *
+                                   TICKS_PER_SECOND_DBL);
+  else xtime = pulsed->audio_ticks * absolute + (int64_t)(frames_written / (double)afile->arate * TICKS_PER_SECOND_DBL);
   return xtime;
 #endif
 }
@@ -1361,8 +1430,7 @@ void pulse_aud_pb_ready(int fileno) {
     if (sfile->achans > 0 && (!mainw->preview || (mainw->preview && mainw->is_processing)) &&
         (sfile->laudio_time > 0. || sfile->opening ||
          (mainw->multitrack != NULL && mainw->multitrack->is_rendering &&
-          lives_file_test((tmpfilename = lives_build_filename(prefs->workdir, sfile->handle, "audio", NULL)),
-                          LIVES_FILE_TEST_EXISTS)))) {
+          lives_file_test((tmpfilename = lives_get_audio_file_name(fileno)), LIVES_FILE_TEST_EXISTS)))) {
       boolean timeout;
       int alarm_handle;
 
@@ -1372,8 +1440,6 @@ void pulse_aud_pb_ready(int fileno) {
       mainw->pulsed->in_arate = sfile->arate;
       mainw->pulsed->usigned = !asigned;
       mainw->pulsed->seek_end = sfile->afilesize;
-      if (sfile->opening) mainw->pulsed->is_opening = TRUE;
-      else mainw->pulsed->is_opening = FALSE;
 
       if ((aendian && (capable->byte_order == LIVES_BIG_ENDIAN)) || (!aendian && (capable->byte_order == LIVES_LITTLE_ENDIAN)))
         mainw->pulsed->reverse_endian = TRUE;
