@@ -1,6 +1,6 @@
 // resample.c
 // LiVES
-// (c) G. Finch 2004 - 2016 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2017 <salsaman+lives@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -28,32 +28,35 @@ static boolean reorder_leave_back = FALSE;
 
 /////////////////////////////////////////////////////
 
-LIVES_INLINE weed_timecode_t q_gint64(weed_timecode_t in, double fps) {
+LIVES_GLOBAL_INLINE weed_timecode_t q_gint64(weed_timecode_t in, double fps) {
   // quantise timecode to fps
-  if (in > (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)U_SEC * (long double)fps + (long double).5) /
-                                         (long double)fps) * (weed_timecode_t)U_SECL; // quantise to frame timing
-  if (in < (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)U_SEC * (long double)fps - (long double).5) /
-                                         (long double)fps) * (weed_timecode_t)U_SECL; // quantise to frame timing
+  if (in > (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)TICKS_PER_SECOND_DBL * (long double)fps +
+                                         (long double).5) /
+                                         (long double)fps) * (weed_timecode_t)TICKS_PER_SECOND; // quantise to frame timing
+  if (in < (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)TICKS_PER_SECOND_DBL * (long double)fps -
+                                         (long double).5) /
+                                         (long double)fps) * (weed_timecode_t)TICKS_PER_SECOND; // quantise to frame timing
   return (weed_timecode_t)0;
 }
 
-LIVES_INLINE weed_timecode_t q_gint64_floor(weed_timecode_t in, double fps) {
-  if (in != (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)U_SEC * (long double)fps) / (long double)fps) *
-                                         (weed_timecode_t)U_SECL; // quantise to frame timing
+LIVES_GLOBAL_INLINE weed_timecode_t q_gint64_floor(weed_timecode_t in, double fps) {
+  if (in != (weed_timecode_t)0) return ((weed_timecode_t)((long double)in / (long double)TICKS_PER_SECOND_DBL * (long double)fps) /
+                                          (long double)fps) *
+                                         (weed_timecode_t)TICKS_PER_SECOND; // quantise to frame timing
   return (weed_timecode_t)0;
 }
 
-LIVES_INLINE weed_timecode_t q_dbl(double in, double fps) {
+LIVES_GLOBAL_INLINE weed_timecode_t q_dbl(double in, double fps) {
   // quantise (double)in to fps
   if (in > 0.) return ((weed_timecode_t)((long double)in * (long double)fps + (long double).5) / (long double)fps) *
-                        (weed_timecode_t)U_SECL; // quantise to frame timing
+                        (weed_timecode_t)TICKS_PER_SECOND; // quantise to frame timing
   if (in < 0.) return ((weed_timecode_t)((long double)in * (long double)fps - (long double).5) / (long double)fps) *
-                        (weed_timecode_t)U_SECL; // quantise to frame timing
+                        (weed_timecode_t)TICKS_PER_SECOND; // quantise to frame timing
   return (weed_timecode_t)0;
 }
 
 
-LIVES_INLINE int count_resampled_frames(int in_frames, double orig_fps, double resampled_fps) {
+LIVES_GLOBAL_INLINE int count_resampled_frames(int in_frames, double orig_fps, double resampled_fps) {
   int res_frames;
   if (resampled_fps < orig_fps) return ((res_frames = (int)((double)in_frames / orig_fps * resampled_fps)) < 1) ? 1 : res_frames;
   else return ((res_frames = (int)((double)in_frames / orig_fps * resampled_fps + .49999)) < 1) ? 1 : res_frames;
@@ -448,7 +451,7 @@ boolean auto_resample_resize(int width, int height, double fps, int fps_num, int
 //////////////////////////////////////////////////////////////////
 
 weed_plant_t *quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
-  // new style event system, now we quantise from event_list_t *in_list to *out_list with period tl/U_SEC
+  // new style event system, now we quantise from event_list_t *in_list to *out_list with period tl/TICKS_PER_SECOND_DBL
 
   // the timecode of the midpoint of our last frame events will match as near as possible the old length
   // but out_list will have regular period of tl microseconds
@@ -492,7 +495,7 @@ weed_plant_t *quantise_events(weed_plant_t *in_list, double qfps, boolean allow_
     tp = tc_end - tp;
   } else {
     // only one event, use cfile->fps
-    tp = (weed_timecode_t)(U_SEC / cfile->fps);
+    tp = (weed_timecode_t)(TICKS_PER_SECOND_DBL / cfile->fps);
   }
 
   tc_end += tp;
@@ -538,7 +541,7 @@ weed_plant_t *quantise_events(weed_plant_t *in_list, double qfps, boolean allow_
         tp -= in_tc;
       } else {
         // only one event, use cfile->fps
-        tp = (weed_timecode_t)(U_SEC / cfile->fps);
+        tp = (weed_timecode_t)(TICKS_PER_SECOND_DBL / cfile->fps);
       }
 #ifdef RESAMPLE_USE_MIDPOINTS
       // calc mid-point of in frame
@@ -742,6 +745,7 @@ void on_resaudio_ok_clicked(LiVESButton *button, LiVESEntry *entry) {
   int arate, achans, asampsize, arps;
   int asigned = 1, aendian = 1;
   int cur_signed, cur_endian;
+  int i;
 
   if (button != NULL) {
     arps = arate = (int)atoi(lives_entry_get_text(LIVES_ENTRY(resaudw->entry_arate)));
@@ -829,6 +833,11 @@ void on_resaudio_ok_clicked(LiVESButton *button, LiVESEntry *entry) {
     }
   }
 
+  if (cfile->audio_waveform != NULL) {
+    for (i = 0; i < cfile->achans; lives_freep((void **)&cfile->audio_waveform[i++]));
+    lives_freep((void **)&cfile->audio_waveform);
+  }
+
   cfile->arate = arate;
   cfile->achans = achans;
   cfile->asampsize = asampsize;
@@ -991,7 +1000,7 @@ void on_resample_vid_ok(LiVESButton *button, LiVESEntry *entry) {
         do_memory_error_dialog();
         return;
       }
-      in_time += (weed_timecode_t)(1. / cfile->fps * U_SEC + .5);
+      in_time += (weed_timecode_t)(1. / cfile->fps * TICKS_PER_SECOND_DBL + .5);
     }
     cfile->event_list = new_event_list;
   }
@@ -1501,7 +1510,7 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
   }
 
   if (type < 3 || type > 4) {
-    cancelbutton = lives_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
+    cancelbutton = lives_standard_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
 
     lives_dialog_add_action_widget(LIVES_DIALOG(resaudw->dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
     lives_widget_set_can_focus_and_default(cancelbutton);
@@ -1509,11 +1518,11 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
     if (accel_group != NULL) lives_widget_add_accelerator(cancelbutton, LIVES_WIDGET_CLICKED_SIGNAL, accel_group,
           LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-    okbutton = lives_button_new_from_stock(LIVES_STOCK_OK, NULL);
+    okbutton = lives_standard_button_new_from_stock(LIVES_STOCK_OK, NULL);
 
     lives_dialog_add_action_widget(LIVES_DIALOG(resaudw->dialog), okbutton, LIVES_RESPONSE_OK);
     lives_widget_set_can_focus_and_default(okbutton);
-    lives_widget_grab_default(okbutton);
+    lives_widget_grab_default_special(okbutton);
 
     if (type < 8 || type == 11) {
       lives_signal_connect(LIVES_GUI_OBJECT(cancelbutton), LIVES_WIDGET_CLICKED_SIGNAL,
@@ -1659,17 +1668,17 @@ void create_new_pb_speed(short type) {
 
   lives_box_pack_start(LIVES_BOX(vbox), ca_hbox, TRUE, TRUE, widget_opts.packing_height);
 
-  cancelbutton = lives_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
+  cancelbutton = lives_standard_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
   lives_dialog_add_action_widget(LIVES_DIALOG(new_pb_speed), cancelbutton, LIVES_RESPONSE_CANCEL);
   lives_widget_set_can_focus(cancelbutton, TRUE);
 
   lives_widget_add_accelerator(cancelbutton, LIVES_WIDGET_CLICKED_SIGNAL, accel_group,
                                LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-  change_pb_ok = lives_button_new_from_stock(LIVES_STOCK_OK, NULL);
+  change_pb_ok = lives_standard_button_new_from_stock(LIVES_STOCK_OK, NULL);
   lives_dialog_add_action_widget(LIVES_DIALOG(new_pb_speed), change_pb_ok, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default(change_pb_ok);
-  lives_widget_grab_default(change_pb_ok);
+  lives_widget_grab_default_special(change_pb_ok);
   lives_widget_grab_focus(spinbutton_pb_speed);
 
   reorder_leave_back = FALSE;
@@ -1984,7 +1993,7 @@ int deorder_frames(int old_frames, boolean leave_bak) {
     perf_end = old_frames;
   } else {
     time_start = get_event_timecode(get_first_event(cfile->event_list));
-    perf_start = (int)(cfile->fps * (double)time_start / U_SEC) + 1;
+    perf_start = (int)(cfile->fps * (double)time_start / TICKS_PER_SECOND_DBL) + 1;
     perf_end = perf_start + count_events(cfile->event_list, FALSE, 0, 0) - 1;
   }
   com = lives_strdup_printf("%s deorder \"%s\" %d %d %d \"%s\" %d", prefs->backend, cfile->handle,
