@@ -1,6 +1,6 @@
 // rte_window.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2016
+// (c) G. Finch 2005 - 2017
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -523,11 +523,11 @@ void on_save_rte_defs_activate(LiVESMenuItem *menuitem, livespointer user_data)
   register int i;
 
   if (prefs->fxdefsfile == NULL) {
-    prefs->fxdefsfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, "fxdefs", NULL);
+    prefs->fxdefsfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, FX_DEFS_FILENAME, NULL);
   }
 
   if (prefs->fxsizesfile == NULL) {
-    prefs->fxsizesfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, "fxsizes", NULL);
+    prefs->fxsizesfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, FX_SIZES_FILENAME, NULL);
   }
 
   d_print(_("Saving real time effect defaults to %s..."), prefs->fxdefsfile);
@@ -541,7 +541,7 @@ void on_save_rte_defs_activate(LiVESMenuItem *menuitem, livespointer user_data)
       retval = do_abort_cancel_retry_dialog(msg, LIVES_WINDOW(rte_window));
       lives_free(msg);
     } else {
-      msg = lives_strdup("LiVES filter defaults file version 1.1\n");
+      msg = lives_strdup_printf("%s\n", FX_DEFS_VERSIONSTRING_1_1);
       mainw->write_failed = FALSE;
       lives_write_buffered(fd, msg, strlen(msg), TRUE);
       lives_free(msg);
@@ -569,7 +569,7 @@ void on_save_rte_defs_activate(LiVESMenuItem *menuitem, livespointer user_data)
       retval = do_write_failed_error_s_with_retry(prefs->fxsizesfile, lives_strerror(errno), LIVES_WINDOW(rte_window));
       lives_free(msg);
     } else {
-      msg = lives_strdup("LiVES generator default sizes file version 2\n");
+      msg = lives_strdup_printf("%s\n", FX_SIZES_VERSIONSTRING_2);
       mainw->write_failed = FALSE;
       lives_write_buffered(fd, msg, strlen(msg), TRUE);
       lives_free(msg);
@@ -609,7 +609,7 @@ void load_rte_defs(void) {
   int retval;
 
   if (prefs->fxdefsfile == NULL) {
-    prefs->fxdefsfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, "fxdefs", NULL);
+    prefs->fxdefsfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, FX_DEFS_FILENAME, NULL);
   }
 
   if (lives_file_test(prefs->fxdefsfile, LIVES_FILE_TEST_EXISTS)) {
@@ -621,7 +621,7 @@ void load_rte_defs(void) {
         mainw->read_failed = FALSE;
         d_print(_("Loading real time effect defaults from %s..."), prefs->fxdefsfile);
 
-        msg = lives_strdup("LiVES filter defaults file version 1.1\n");
+        msg = lives_strdup_printf("%s\n", FX_DEFS_VERSIONSTRING_1_1);
         buf = lives_malloc(strlen(msg));
         bytes = lives_read_buffered(fd, buf, strlen(msg), TRUE);
 
@@ -648,7 +648,7 @@ void load_rte_defs(void) {
   }
 
   if (prefs->fxsizesfile == NULL) {
-    prefs->fxsizesfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, "fxsizes", NULL);
+    prefs->fxsizesfile = lives_build_filename(capable->home_dir, LIVES_CONFIG_DIR, FX_SIZES_FILENAME, NULL);
   }
 
   if (lives_file_test(prefs->fxsizesfile, LIVES_FILE_TEST_EXISTS)) {
@@ -660,7 +660,7 @@ void load_rte_defs(void) {
       } else {
         d_print(_("Loading generator default sizes from %s..."), prefs->fxsizesfile);
 
-        msg = lives_strdup("LiVES generator default sizes file version 2\n");
+        msg = lives_strdup_printf("%s\n", FX_SIZES_VERSIONSTRING_2);
         buf = lives_malloc(strlen(msg));
         bytes = lives_read_buffered(fd, buf, strlen(msg), TRUE);
         if (bytes == strlen(msg) && !strncmp((char *)buf, msg, strlen(msg))) {
@@ -1508,7 +1508,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
     } else d_print_done();
   } else {
     if (kfd != -1) lives_close_buffered(kfd);
-    d_print_done();
+    if (mainw->is_ready) d_print_done();
   }
 
   if (update == 0) {
@@ -1684,7 +1684,7 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
     lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
   }
 
-  ok_button = lives_button_new_from_stock(LIVES_STOCK_OK, NULL);
+  ok_button = lives_standard_button_new_from_stock(LIVES_STOCK_OK, NULL);
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), ok_button, LIVES_RESPONSE_OK);
 
   abox = lives_dialog_get_action_area(LIVES_DIALOG(dialog));
@@ -1695,7 +1695,7 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
 #endif
 
   lives_widget_set_can_focus_and_default(ok_button);
-  lives_widget_grab_default(ok_button);
+  lives_widget_grab_default_special(ok_button);
 
   lives_widget_set_size_request(ok_button, DEF_BUTTON_WIDTH * 4, -1);
 
@@ -2084,8 +2084,6 @@ LiVESWidget *create_rte_window(void) {
   int winsize_h;
   int winsize_v;
 
-  int scr_width, scr_height;
-
   register int i, j;
 
   ///////////////////////////////////////////////////////////////////////////
@@ -2093,16 +2091,8 @@ LiVESWidget *create_rte_window(void) {
   lives_set_cursor_style(LIVES_CURSOR_BUSY, NULL);
   lives_widget_context_update();
 
-  if (prefs->gui_monitor == 0) {
-    scr_width = mainw->scr_width;
-    scr_height = mainw->scr_height;
-  } else {
-    scr_width = mainw->mgeom[prefs->gui_monitor - 1].width;
-    scr_height = mainw->mgeom[prefs->gui_monitor - 1].height;
-  }
-
-  winsize_h = scr_width - 100;
-  winsize_v = scr_height - 200;
+  winsize_h = GUI_SCREEN_WIDTH - SCR_WIDTH_SAFETY;
+  winsize_v = GUI_SCREEN_HEIGHT - SCR_HEIGHT_SAFETY;
 
   if (rte_window_back != NULL) {
     rte_window = rte_window_back;
@@ -2194,7 +2184,7 @@ LiVESWidget *create_rte_window(void) {
 
     mode_group = NULL;
 
-    clear_all_button = lives_button_new_from_stock(LIVES_STOCK_CLEAR, _("_Clear all effects"));
+    clear_all_button = lives_standard_button_new_from_stock(LIVES_STOCK_CLEAR, _("_Clear all effects"));
 
     for (j = 0; j < modes; j++) {
       idx = i * modes + j;
@@ -2216,10 +2206,10 @@ LiVESWidget *create_rte_window(void) {
 
       type_labels[idx] = lives_standard_label_new("");
 
-      info_buttons[idx] = lives_button_new_with_label(_("Info"));
-      param_buttons[idx] = lives_button_new_with_label(_("Set Parameters"));
-      conx_buttons[idx] = lives_button_new_with_label(_("Set Connections"));
-      clear_buttons[idx] = lives_button_new_with_label(_("Clear"));
+      info_buttons[idx] = lives_standard_button_new_with_label(_("Info"));
+      param_buttons[idx] = lives_standard_button_new_with_label(_("Set Parameters"));
+      conx_buttons[idx] = lives_standard_button_new_with_label(_("Set Connections"));
+      clear_buttons[idx] = lives_standard_button_new_with_label(_("Clear"));
 
       vbox = lives_vbox_new(FALSE, 0);
       lives_box_pack_start(LIVES_BOX(hbox), vbox, FALSE, FALSE, widget_opts.packing_width);
@@ -2296,17 +2286,17 @@ LiVESWidget *create_rte_window(void) {
   lives_container_add(LIVES_CONTAINER(hbuttonbox), clear_all_button);
   lives_widget_set_can_focus_and_default(clear_all_button);
 
-  save_keymap_button = lives_button_new_from_stock(LIVES_STOCK_SAVE_AS, _("_Save as default keymap"));
+  save_keymap_button = lives_standard_button_new_from_stock(LIVES_STOCK_SAVE_AS, _("_Save as default keymap"));
 
   lives_container_add(LIVES_CONTAINER(hbuttonbox), save_keymap_button);
   lives_widget_set_can_focus_and_default(save_keymap_button);
 
-  load_keymap_button = lives_button_new_from_stock(LIVES_STOCK_OPEN, _("_Load default keymap"));
+  load_keymap_button = lives_standard_button_new_from_stock(LIVES_STOCK_OPEN, _("_Load default keymap"));
 
   lives_container_add(LIVES_CONTAINER(hbuttonbox), load_keymap_button);
   lives_widget_set_can_focus_and_default(load_keymap_button);
 
-  ok_button = lives_button_new_from_stock(LIVES_STOCK_CLOSE, _("Close _window"));
+  ok_button = lives_standard_button_new_from_stock(LIVES_STOCK_CLOSE, _("Close _window"));
 
   lives_container_add(LIVES_CONTAINER(hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default(ok_button);
@@ -2354,12 +2344,7 @@ rte_window_ready:
   lives_widget_hide(dummy_radio);
 
   if (prefs->gui_monitor != 0) {
-    int xcen = mainw->mgeom[prefs->gui_monitor - 1].x + (mainw->mgeom[prefs->gui_monitor - 1].width -
-               lives_widget_get_allocation_width(rte_window)) / 2;
-    int ycen = mainw->mgeom[prefs->gui_monitor - 1].y + (mainw->mgeom[prefs->gui_monitor - 1].height -
-               lives_widget_get_allocation_height(rte_window)) / 2;
-    lives_window_set_screen(LIVES_WINDOW(rte_window), mainw->mgeom[prefs->gui_monitor - 1].screen);
-    lives_window_move(LIVES_WINDOW(rte_window), xcen, ycen);
+    lives_window_center(LIVES_WINDOW(rte_window));
   }
 
   if (prefs->open_maximised) {
