@@ -1,6 +1,6 @@
 // startup.c
 // LiVES
-// (c) G. Finch 2010 - 2016 <salsaman@gmail.com>
+// (c) G. Finch 2010 - 2017 <salsaman+lives@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -364,18 +364,18 @@ boolean do_audio_choice_dialog(short startup_phase) {
                          LIVES_INT_TO_POINTER(AUD_PLAYER_MPLAYER2));
   }
 
-  cancelbutton = lives_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
+  cancelbutton = lives_standard_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
 
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
 
   lives_widget_add_accelerator(cancelbutton, LIVES_WIDGET_CLICKED_SIGNAL, accel_group,
                                LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-  okbutton = lives_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Next"));
+  okbutton = lives_standard_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Next"));
 
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default(okbutton);
-  lives_widget_grab_default(okbutton);
+  lives_widget_grab_default_special(okbutton);
   lives_widget_grab_focus(okbutton);
 
   if (prefs->audio_player == -1) {
@@ -472,8 +472,8 @@ static boolean fail_test(LiVESWidget *table, int row, char *ftext) {
 }
 
 
-static LIVES_INLINE char *get_resource(char *fname) {
-  return lives_strdup_printf("%s%sresources/%s", prefs->prefix_dir, DATA_DIR, fname);
+LIVES_INLINE char *get_resource(char *fname) {
+  return lives_build_filename(prefs->prefix_dir, DATA_DIR, "resources", fname, NULL);
 }
 
 
@@ -538,7 +538,7 @@ boolean do_startup_tests(boolean tshoot) {
   label = lives_standard_label_new(_("LiVES will now run some basic configuration tests\n"));
   lives_container_add(LIVES_CONTAINER(dialog_vbox), label);
 
-  cancelbutton = lives_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
+  cancelbutton = lives_standard_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
 
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
 
@@ -546,12 +546,12 @@ boolean do_startup_tests(boolean tshoot) {
                                LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
   if (!tshoot) {
-    okbutton = lives_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Next"));
-  } else okbutton = lives_button_new_from_stock(LIVES_STOCK_OK, NULL);
+    okbutton = lives_standard_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Next"));
+  } else okbutton = lives_standard_button_new_from_stock(LIVES_STOCK_OK, NULL);
 
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default(okbutton);
-  lives_widget_grab_default(okbutton);
+  lives_widget_grab_default_special(okbutton);
   lives_widget_grab_focus(okbutton);
 
   lives_widget_set_sensitive(okbutton, FALSE);
@@ -588,7 +588,7 @@ boolean do_startup_tests(boolean tshoot) {
     lives_rm(cfile->info_file);
 
     // write 1 second of silence
-    afile = lives_build_filename(prefs->workdir, cfile->handle, "audio", NULL);
+    afile = lives_get_audio_file_name(mainw->current_file);
     out_fd = lives_open3(afile, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR);
 
     if (out_fd < 0) mainw->write_failed = TRUE;
@@ -977,11 +977,11 @@ void do_startup_interface_query(void) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton), TRUE);
   }
 
-  okbutton = lives_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Finish"));
+  okbutton = lives_standard_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Finish"));
 
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default(okbutton);
-  lives_widget_grab_default(okbutton);
+  lives_widget_grab_default_special(okbutton);
   lives_widget_grab_focus(okbutton);
 
   lives_widget_show_all(dialog);
