@@ -7,6 +7,13 @@
 #ifndef HAS_LIVES_WIDGET_HELPER_H
 #define HAS_LIVES_WIDGET_HELPER_H
 
+#ifndef IS_SOLARIS
+#define WIDGET_HELPER_GLOBAL_INLINE inline
+#define WIDGET_HELPER_LOCAL_INLINE static inline
+#else
+#define WIDGET_HELPER_GLOBAL_INLINE
+#define WIDGET_HELPER_LOCAL_INLINE
+#endif
 
 #ifndef M_PI
 #define M_PI 3.1415926536
@@ -23,7 +30,6 @@ typedef enum {
   LIVES_DISPLAY_TYPE_WAYLAND
 } lives_display_t;
 
-
 #define W_PACKING_WIDTH  10 // packing width for widgets with labels
 #define W_PACKING_HEIGHT 10 // packing height for widgets
 #define W_BORDER_WIDTH   10 // default border width
@@ -76,7 +82,6 @@ boolean lives_painter_set_operator(lives_painter_t *, lives_painter_operator_t);
 
 boolean lives_painter_set_fill_rule(lives_painter_t *, lives_painter_fill_rule_t);
 
-
 lives_painter_surface_t *lives_painter_get_target(lives_painter_t *);
 int lives_painter_format_stride_for_width(lives_painter_format_t, int width);
 
@@ -86,9 +91,6 @@ int lives_painter_image_surface_get_height(lives_painter_surface_t *);
 int lives_painter_image_surface_get_stride(lives_painter_surface_t *);
 lives_painter_format_t lives_painter_image_surface_get_format(lives_painter_surface_t *);
 
-
-
-
 // utils
 
 boolean widget_helper_init(void);
@@ -96,12 +98,12 @@ boolean widget_helper_init(void);
 boolean widget_color_to_lives_rgba(lives_colRGBA64_t *, LiVESWidgetColor *);
 boolean lives_rgba_to_widget_color(LiVESWidgetColor *, lives_colRGBA64_t *);
 
-void lives_painter_set_source_rgb_from_lives_rgba(lives_painter_t *cr, lives_colRGBA64_t *col);
-void lives_painter_set_source_rgb_from_lives_rgb(lives_painter_t *cr, lives_colRGB48_t *col);
+boolean lives_painter_set_source_rgb_from_lives_rgba(lives_painter_t *, lives_colRGBA64_t *);
+boolean lives_painter_set_source_rgb_from_lives_rgb(lives_painter_t *, lives_colRGB48_t *);
+boolean lives_painter_set_source_rgb_from_lives_widget_color(lives_painter_t *, LiVESWidgetColor *);
 
 boolean lives_rgba_equal(lives_colRGBA64_t *col1, lives_colRGBA64_t *col2);
-void lives_rgba_copy(lives_colRGBA64_t *col1, lives_colRGBA64_t *col2);
-
+boolean lives_rgba_copy(lives_colRGBA64_t *col1, lives_colRGBA64_t *col2);
 
 // object funcs.
 
@@ -119,7 +121,6 @@ void lives_object_ref_sink(livespointer);
 livespointer lives_object_ref_sink(livespointer);
 #endif
 
-
 // lives_pixbuf functions
 
 int lives_pixbuf_get_width(const LiVESPixbuf *);
@@ -139,7 +140,6 @@ LiVESWidget *lives_image_new_from_pixbuf(LiVESPixbuf *);
 LiVESPixbuf *lives_pixbuf_new_from_file_at_scale(const char *filename, int width, int height, boolean preserve_aspect_ratio,
     LiVESError **error);
 
-
 LiVESPixbuf *lives_pixbuf_scale_simple(const LiVESPixbuf *src, int dest_width, int dest_height,
                                        LiVESInterpType interp_type);
 
@@ -147,7 +147,6 @@ boolean lives_pixbuf_saturate_and_pixelate(const LiVESPixbuf *src, LiVESPixbuf *
 
 // basic widget fns (TODO - amend all void to return boolean)
 
-
 #ifdef GUI_GTK
 
 #define lives_signal_connect(instance, detailed_signal, c_handler, data) g_signal_connect(instance, detailed_signal, c_handler, data)
@@ -212,7 +211,6 @@ LiVESWidget *lives_label_get_mnemonic_widget(LiVESLabel *);
 
 boolean lives_label_set_selectable(LiVESLabel *, boolean setting);
 
-
 LiVESWidget *lives_button_new(void);
 LiVESWidget *lives_button_new_from_stock(const char *stock_id, const char *label);
 LiVESWidget *lives_button_new_with_label(const char *label);
@@ -297,8 +295,6 @@ boolean lives_window_add_accel_group(LiVESWindow *, LiVESAccelGroup *group);
 boolean lives_window_remove_accel_group(LiVESWindow *, LiVESAccelGroup *group);
 boolean lives_menu_set_accel_group(LiVESMenu *, LiVESAccelGroup *group);
 
-boolean lives_window_has_toplevel_focus(LiVESWindow *);
-
 LiVESAdjustment *lives_adjustment_new(double value, double lower, double upper,
                                       double step_increment, double page_increment, double page_size);
 
@@ -336,7 +332,7 @@ LiVESWidget *lives_vscrollbar_new(LiVESAdjustment *);
 LiVESWidget *lives_arrow_new(LiVESArrowType, LiVESShadowType);
 
 LiVESWidget *lives_alignment_new(float xalign, float yalign, float xscale, float yscale);
-boolean lives_alignment_set(LiVESAlignment *, float xalign, float yalign, float xscale, float yscale);
+boolean lives_alignment_set(LiVESWidget *, float xalign, float yalign, float xscale, float yscale);
 
 LiVESWidget *lives_expander_new_with_mnemonic(const char *label);
 LiVESWidget *lives_expander_new(const char *label);
@@ -373,10 +369,8 @@ boolean lives_text_view_set_cursor_visible(LiVESTextView *, boolean setting);
 boolean lives_text_view_set_wrap_mode(LiVESTextView *, LiVESWrapMode wrapmode);
 boolean lives_text_view_set_justification(LiVESTextView *, LiVESJustification justify);
 
-
 boolean lives_text_view_scroll_mark_onscreen(LiVESTextView *, LiVESTextMark *mark);
 
-
 LiVESTextBuffer *lives_text_buffer_new(void);
 char *lives_text_buffer_get_text(LiVESTextBuffer *tbuff, LiVESTextIter *start, LiVESTextIter *end, boolean inc_hidden_chars);
 boolean lives_text_buffer_set_text(LiVESTextBuffer *, const char *, int len);
@@ -397,7 +391,6 @@ boolean lives_text_buffer_delete(LiVESTextBuffer *, LiVESTextIter *start, LiVEST
 
 boolean lives_text_buffer_get_iter_at_mark(LiVESTextBuffer *, LiVESTextIter *, LiVESTextMark *);
 
-
 boolean lives_tree_model_get(LiVESTreeModel *, LiVESTreeIter *, ...);
 boolean lives_tree_model_get_iter(LiVESTreeModel *, LiVESTreeIter *, LiVESTreePath *);
 boolean lives_tree_model_get_iter_first(LiVESTreeModel *, LiVESTreeIter *);
@@ -424,7 +417,6 @@ boolean lives_tree_view_set_headers_visible(LiVESTreeView *, boolean vis);
 LiVESAdjustment *lives_tree_view_get_hadjustment(LiVESTreeView *);
 LiVESTreeSelection *lives_tree_view_get_selection(LiVESTreeView *);
 
-
 LiVESTreeViewColumn *lives_tree_view_column_new_with_attributes(const char *title, LiVESCellRenderer *, ...);
 boolean lives_tree_view_column_set_sizing(LiVESTreeViewColumn *, LiVESTreeViewColumnSizing type);
 boolean lives_tree_view_column_set_fixed_width(LiVESTreeViewColumn *, int fwidth);
@@ -450,6 +442,10 @@ boolean lives_toggle_button_get_active(LiVESToggleButton *);
 boolean lives_toggle_button_set_active(LiVESToggleButton *, boolean active);
 boolean lives_toggle_button_set_mode(LiVESToggleButton *, boolean drawind);
 
+LiVESWidget *lives_toggle_tool_button_new(void);
+boolean lives_toggle_tool_button_get_active(LiVESToggleToolButton *);
+boolean lives_toggle_tool_button_set_active(LiVESToggleToolButton *, boolean active);
+
 boolean lives_has_icon(const char *stock_id, LiVESIconSize size);
 
 void lives_tooltips_set(LiVESWidget *, const char *tip_text);
@@ -507,6 +503,7 @@ boolean lives_color_button_set_use_alpha(LiVESColorButton *, boolean use_alpha);
 
 LiVESToolItem *lives_tool_button_new(LiVESWidget *icon_widget, const char *label);
 LiVESToolItem *lives_tool_item_new(void);
+LiVESToolItem *lives_separator_tool_item_new(void);
 boolean lives_tool_button_set_icon_widget(LiVESToolButton *, LiVESWidget *icon);
 boolean lives_tool_button_set_label_widget(LiVESToolButton *, LiVESWidget *label);
 boolean lives_tool_button_set_use_underline(LiVESToolButton *, boolean use_underline);
@@ -566,7 +563,6 @@ double lives_range_get_value(LiVESRange *);
 boolean lives_editable_set_editable(LiVESEditable *, boolean editable);
 boolean lives_editable_select_region(LiVESEditable *, int start_pos, int end_pos);
 
-
 LiVESWidget *lives_entry_new(void);
 boolean lives_entry_set_editable(LiVESEntry *, boolean editable);
 const char *lives_entry_get_text(LiVESEntry *);
@@ -576,6 +572,7 @@ boolean lives_entry_set_max_length(LiVESEntry *, int len);
 boolean lives_entry_set_activates_default(LiVESEntry *, boolean act);
 boolean lives_entry_set_visibility(LiVESEntry *, boolean vis);
 boolean lives_entry_set_has_frame(LiVESEntry *, boolean has);
+boolean lives_entry_set_alignment(LiVESEntry *, float align);
 
 double lives_scale_button_get_value(LiVESScaleButton *);
 boolean lives_scale_button_set_value(LiVESScaleButton *, double value);
@@ -591,7 +588,6 @@ boolean lives_table_attach(LiVESTable *, LiVESWidget *child, uint32_t left, uint
 boolean lives_table_set_column_homogeneous(LiVESTable *, boolean homogeneous);
 boolean lives_table_set_row_homogeneous(LiVESTable *, boolean homogeneous);
 
-
 #if LIVES_TABLE_IS_GRID
 LiVESWidget *lives_grid_new(void);
 boolean lives_grid_set_row_spacing(LiVESGrid *, uint32_t spacing);
@@ -632,6 +628,8 @@ LiVESWidget *lives_menu_item_new(void);
 LiVESWidget *lives_menu_item_new_with_mnemonic(const char *label);
 LiVESWidget *lives_menu_item_new_with_label(const char *label);
 
+boolean lives_menu_item_set_accel_path(LiVESMenuItem *, const char *path);
+
 LiVESWidget *lives_check_menu_item_new_with_mnemonic(const char *label);
 LiVESWidget *lives_check_menu_item_new_with_label(const char *label);
 boolean lives_check_menu_item_set_draw_as_radio(LiVESCheckMenuItem *, boolean setting);
@@ -644,7 +642,6 @@ LiVESWidget *lives_image_menu_item_new_from_stock(const char *stock_id, LiVESAcc
 LiVESToolItem *lives_menu_tool_button_new(LiVESWidget *icon, const char *label);
 boolean lives_menu_tool_button_set_menu(LiVESMenuToolButton *, LiVESWidget *menu);
 
-
 #if !GTK_CHECK_VERSION(3, 10, 0)
 
 boolean lives_image_menu_item_set_image(LiVESImageMenuItem *, LiVESWidget *image);
@@ -660,10 +657,8 @@ boolean lives_check_menu_item_get_active(LiVESCheckMenuItem *);
 
 boolean lives_menu_set_title(LiVESMenu *, const char *title);
 
-
 int lives_display_get_n_screens(LiVESXDisplay *);
 
-
 char *lives_file_chooser_get_filename(LiVESFileChooser *);
 LiVESSList *lives_file_chooser_get_filenames(LiVESFileChooser *);
 
@@ -685,6 +680,7 @@ boolean lives_widget_add_accelerator(LiVESWidget *, const char *accel_signal, Li
                                      uint32_t accel_key, LiVESXModifierType accel_mods, LiVESAccelFlags accel_flags);
 
 boolean lives_widget_get_pointer(LiVESXDevice *, LiVESWidget *, int *x, int *y);
+boolean lives_widget_get_modmask(LiVESXDevice *, LiVESWidget *, LiVESXModifierType *modmask);
 LiVESXWindow *lives_display_get_window_at_pointer(LiVESXDevice *, LiVESXDisplay *, int *win_x, int *win_y);
 boolean lives_display_get_pointer(LiVESXDevice *, LiVESXDisplay *, LiVESXScreen **, int *x, int *y, LiVESXModifierType *mask);
 boolean lives_display_warp_pointer(LiVESXDevice *, LiVESXDisplay *, LiVESXScreen *, int x, int y);
@@ -694,7 +690,6 @@ lives_display_t lives_widget_get_display_type(LiVESWidget *);
 
 uint64_t lives_widget_get_xwinid(LiVESWidget *, const char *failure_msg);
 
-
 LiVESWidget *lives_scrolled_window_new(LiVESAdjustment *hadj, LiVESAdjustment *vadj);
 LiVESAdjustment *lives_scrolled_window_get_hadjustment(LiVESScrolledWindow *);
 LiVESAdjustment *lives_scrolled_window_get_vadjustment(LiVESScrolledWindow *);
@@ -719,6 +714,8 @@ boolean lives_scale_set_draw_value(LiVESScale *, boolean draw_value);
 boolean lives_scale_set_value_pos(LiVESScale *, LiVESPositionType ptype);
 boolean lives_scale_set_digits(LiVESScale *, int digits);
 
+boolean lives_has_toplevel_focus(LiVESWidget *window);
+
 // optional (return TRUE if implemented)
 
 boolean lives_dialog_set_has_separator(LiVESDialog *, boolean has);
@@ -728,17 +725,37 @@ boolean lives_image_menu_item_set_always_show_image(LiVESImageMenuItem *, boolea
 boolean lives_scale_button_set_orientation(LiVESScaleButton *, LiVESOrientation orientation);
 boolean lives_window_set_auto_startup_notification(boolean set);
 
-
-
-
 // compound functions (composed of basic functions)
-boolean lives_has_toplevel_focus();
 
 void lives_label_set_hpadding(LiVESLabel *label, int pad);
 
+boolean lives_widget_grab_default_special(LiVESWidget *);
+
+#define BUTTON_DIM_VAL 24000
+
+LiVESWidget *lives_standard_button_new(void);
+LiVESWidget *lives_standard_button_new_with_mnemonic(const char *label);
+LiVESWidget *lives_standard_button_new_with_label(const char *label);
+LiVESWidget *lives_standard_button_new_from_stock(const char *stock_id, const char *label);
+
+LiVESWidget *lives_standard_menu_item_new(void);
+LiVESWidget *lives_standard_menu_item_new_with_mnemonic(const char *label);
+LiVESWidget *lives_standard_menu_item_new_with_label(const char *label);
+
+LiVESWidget *lives_standard_image_menu_item_new_with_label(const char *label);
+LiVESWidget *lives_standard_image_menu_item_new_with_mnemonic(const char *label);
+LiVESWidget *lives_standard_image_menu_item_new_from_stock(const char *stock_id, LiVESAccelGroup *accel_group);
+
+LiVESWidget *lives_standard_radio_menu_item_new_with_label(LiVESSList *group, const char *label);
+
+LiVESWidget *lives_standard_check_menu_item_new_with_label(const char *label);
+LiVESWidget *lives_standard_check_menu_item_new_with_mnemonic(const char *label);
+
 LiVESWidget *lives_standard_label_new(const char *text);
 LiVESWidget *lives_standard_label_new_with_mnemonic(const char *text, LiVESWidget *mnemonic_widget);
 
+LiVESWidget *lives_standard_drawing_area_new(LiVESGuiCallback callback, ulong *ret_fn);
+
 LiVESWidget *lives_standard_frame_new(const char *labeltext, float xalign, boolean invisible_outline);
 
 LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_mnemonic, LiVESBox *box, const char *tooltip);
@@ -770,7 +787,6 @@ LiVESWidget *lives_standard_color_button_new(LiVESBox *parent, char *name, boole
 
 LiVESWidget *lives_standard_text_view_new(const char *text, LiVESTextBuffer *tbuff);
 
-
 LiVESXCursor *lives_cursor_new_from_pixbuf(LiVESXDisplay *, LiVESPixbuf *, int x, int y);
 
 // util functions
@@ -800,34 +816,31 @@ void lives_tooltips_copy(LiVESWidget *dest, LiVESWidget *source);
 char *lives_text_view_get_text(LiVESTextView *);
 boolean lives_text_view_set_text(LiVESTextView *, const char *text, int len);
 
-
 boolean lives_text_buffer_insert_at_end(LiVESTextBuffer *, const char *text);
 boolean lives_text_view_scroll_onscreen(LiVESTextView *);
 
-
-
-
 void lives_general_button_clicked(LiVESButton *, livespointer data_to_free);
 
 void lives_spin_button_configure(LiVESSpinButton *, double value, double lower, double upper,
                                  double step_increment, double page_increment);
 
-
-
 size_t calc_spin_button_width(double min, double max, int dp);
 
 int get_box_child_index(LiVESBox *, LiVESWidget *child);
 
+boolean lives_container_child_set_shrinkable(LiVESContainer *, LiVESWidget *child, boolean val);
+
 boolean label_act_toggle(LiVESWidget *, LiVESXEventButton *, LiVESToggleButton *);
 boolean widget_act_toggle(LiVESWidget *, LiVESToggleButton *);
 
 void toggle_button_toggle(LiVESToggleButton *);
 
-
-void set_child_colour(LiVESWidget *widget, boolean set_all);
-void set_child_alt_colour(LiVESWidget *widget, boolean set_all);
+void set_child_colour(LiVESWidget *, boolean set_all);
+void set_child_alt_colour(LiVESWidget *, boolean set_all);
 
 void funkify_dialog(LiVESWidget *dialog);
+boolean draw_cool_toggle(LiVESWidget *, lives_painter_t *, livespointer);
+void lives_cool_toggled(LiVESWidget *tbutton, livespointer);
 
 void unhide_cursor(LiVESXWindow *);
 void hide_cursor(LiVESXWindow *);
@@ -839,13 +852,19 @@ LiVESWidget *add_vsep_to_box(LiVESBox *);
 
 LiVESWidget *add_fill_to_box(LiVESBox *);
 
+LiVESWidget *lives_toolbar_insert_space(LiVESToolbar *);
+LiVESWidget *lives_toolbar_insert_label(LiVESToolbar *, const char *text);
+
+boolean lives_accel_path_disconnect(LiVESAccelGroup *group, const char *path);
+
+boolean lives_widget_get_mod_mask(LiVESWidget *, LiVESXModifierType *modmask);
+
 #endif // cplusplus
 
 #define LIVES_JUSTIFY_DEFAULT (widget_opts.default_justify)
 
 #define W_MAX_FILLER_LEN 65535
 
-
 typedef enum {
   LIVES_CURSOR_NORMAL = 0, ///< must be zero
   LIVES_CURSOR_BUSY,
@@ -871,7 +890,6 @@ typedef enum {
   LIVES_EXPAND_EXTRA
 } lives_expand_t;
 
-
 typedef struct {
   boolean no_gui; // show nothing !
   boolean swap_label; // swap label/widget position
@@ -890,9 +908,11 @@ typedef struct {
   LiVESJustification default_justify;
   char **image_filter; /// NULL or NULL terminated list of image extensions which can be loaded
   char *title_prefix; // Text which is prepended to window titles, etc.
+  int monitor;
+  LiVESXScreen *screen;
+  boolean show_button_images;
 } widget_opts_t;
 
-
 widget_opts_t widget_opts;
 
 #ifdef NEED_DEF_WIDGET_OPTS
@@ -914,7 +934,10 @@ const widget_opts_t def_widget_opts = {
   LIVES_JUSTIFY_LEFT, // justify
   LIVES_JUSTIFY_LEFT, // default justify
   NULL, // image_filter
-  "" // title_prefix
+  "", // title_prefix
+  0, // monitor
+  NULL, // screen
+  FALSE // show button images
 };
 
 #else
